# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.candidate_criteria_schema import CandidateCriteriaSchema
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from smartytalent_client.models.talent_alumni_schema import TalentAlumniSchema
from smartytalent_client.models.talent_referral_schema import TalentReferralSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class CandidateAttributesSchema(BaseModel):
    """
    CandidateAttributesSchema
    """ # noqa: E501
    name: StrictStr = Field(description="Full name of the candidate")
    email: StrictStr = Field(description="Primary email address")
    secondary_email: Optional[StrictStr] = Field(default=None, description="Secondary email address", alias="secondaryEmail")
    work_email: Optional[StrictStr] = Field(default=None, description="Work email address", alias="workEmail")
    phone: Optional[StrictStr] = Field(default=None, description="Primary phone number")
    work_phone: Optional[StrictStr] = Field(default=None, description="Work phone number", alias="workPhone")
    status: Optional[StrictStr] = Field(default=None, description="Current status of the candidate")
    stage: Optional[StrictStr] = Field(default=None, description="Current stage in the recruitment pipeline")
    age: Optional[StrictStr] = Field(default=None, description="Candidate age")
    gender: Optional[StrictStr] = Field(default=None, description="Candidate gender")
    source: Optional[StrictStr] = Field(default=None, description="Source of the candidate (e.g., referral, job board)")
    short_code: Optional[StrictStr] = Field(default=None, description="Short code identifier for the candidate", alias="shortCode")
    language_code: Optional[StrictStr] = Field(default=None, description="Preferred language code (e.g., en-US, pl-PL)", alias="languageCode")
    recommendation_status_code: Optional[StrictInt] = Field(default=None, description="Numeric recommendation status code", alias="recommendationStatusCode")
    overall_match_rating: Optional[StrictInt] = Field(default=None, description="Overall match rating (0-5)", alias="overallMatchRating")
    prev_overall_match_rating: Optional[StrictInt] = Field(default=None, description="Previous overall match rating before recalculation", alias="prevOverallMatchRating")
    ttl: Optional[StrictStr] = Field(default=None, description="Time-to-live expiration timestamp")
    timestamps: Optional[ResourceTimestampsSchema] = None
    alumni: Optional[TalentAlumniSchema] = None
    referral: Optional[TalentReferralSchema] = None
    job_position_title: Optional[Dict[str, StrictStr]] = Field(default=None, description="Language-keyed job position title", alias="jobPositionTitle")
    rejection_ticket: Optional[Dict[str, StrictStr]] = Field(default=None, description="Language-keyed rejection ticket text", alias="rejectionTicket")
    recommendation_status: Optional[Dict[str, Dict[str, Any]]] = Field(default=None, description="Language-keyed recommendation status", alias="recommendationStatus")
    overall_assessment: Optional[Dict[str, Dict[str, Any]]] = Field(default=None, description="Language-keyed overall assessment", alias="overallAssessment")
    next_steps: Optional[Dict[str, Dict[str, Any]]] = Field(default=None, description="Language-keyed next steps recommendations", alias="nextSteps")
    insights_and_analysis: Optional[Dict[str, Dict[str, Any]]] = Field(default=None, description="Language-keyed insights and analysis", alias="insightsAndAnalysis")
    keywords: Optional[Dict[str, Dict[str, Any]]] = Field(default=None, description="Language-keyed extracted keywords")
    availability: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed availability criteria")
    certifications: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed certifications criteria")
    company_type_experience: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed company type experience criteria", alias="companyTypeExperience")
    education: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed education criteria")
    experience_and_seniority: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed experience and seniority criteria", alias="experienceAndSeniority")
    industry_experience: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed industry experience criteria", alias="industryExperience")
    job_positions: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed job positions criteria", alias="jobPositions")
    job_tendencies: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed job tendencies criteria", alias="jobTendencies")
    languages_spoken: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed languages spoken criteria", alias="languagesSpoken")
    licenses: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed licenses criteria")
    location_preferences: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed location preferences criteria", alias="locationPreferences")
    personality_and_soft_skills: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed personality and soft skills criteria", alias="personalityAndSoftSkills")
    salary_expectation: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed salary expectation criteria", alias="salaryExpectation")
    skills_and_expertise: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed skills and expertise criteria", alias="skillsAndExpertise")
    work_authorization: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed work authorization criteria", alias="workAuthorization")
    work_preferences: Optional[Dict[str, CandidateCriteriaSchema]] = Field(default=None, description="Language-keyed work preferences criteria", alias="workPreferences")
    __properties: ClassVar[List[str]] = ["name", "email", "secondaryEmail", "workEmail", "phone", "workPhone", "status", "stage", "age", "gender", "source", "shortCode", "languageCode", "recommendationStatusCode", "overallMatchRating", "prevOverallMatchRating", "ttl", "timestamps", "alumni", "referral", "jobPositionTitle", "rejectionTicket", "recommendationStatus", "overallAssessment", "nextSteps", "insightsAndAnalysis", "keywords", "availability", "certifications", "companyTypeExperience", "education", "experienceAndSeniority", "industryExperience", "jobPositions", "jobTendencies", "languagesSpoken", "licenses", "locationPreferences", "personalityAndSoftSkills", "salaryExpectation", "skillsAndExpertise", "workAuthorization", "workPreferences"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'withdrawn', 'rejected', 'inactive', 'onHold', 'offerExtended', 'offerDeclined', 'futureConsideration', 'archived']):
            raise ValueError("must be one of enum values ('active', 'withdrawn', 'rejected', 'inactive', 'onHold', 'offerExtended', 'offerDeclined', 'futureConsideration', 'archived')")
        return value

    @field_validator('stage')
    def stage_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['sourced', 'applied', 'initial', 'prescreened', 'screened', 'assessed', 'contacted', 'interviewed', 'offered', 'hired', 'onboarded', 'evaluated']):
            raise ValueError("must be one of enum values ('sourced', 'applied', 'initial', 'prescreened', 'screened', 'assessed', 'contacted', 'interviewed', 'offered', 'hired', 'onboarded', 'evaluated')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CandidateAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of alumni
        if self.alumni:
            _dict['alumni'] = self.alumni.to_dict()
        # override the default output from pydantic by calling `to_dict()` of referral
        if self.referral:
            _dict['referral'] = self.referral.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in availability (dict)
        _field_dict = {}
        if self.availability:
            for _key_availability in self.availability:
                if self.availability[_key_availability]:
                    _field_dict[_key_availability] = self.availability[_key_availability].to_dict()
            _dict['availability'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in certifications (dict)
        _field_dict = {}
        if self.certifications:
            for _key_certifications in self.certifications:
                if self.certifications[_key_certifications]:
                    _field_dict[_key_certifications] = self.certifications[_key_certifications].to_dict()
            _dict['certifications'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in company_type_experience (dict)
        _field_dict = {}
        if self.company_type_experience:
            for _key_company_type_experience in self.company_type_experience:
                if self.company_type_experience[_key_company_type_experience]:
                    _field_dict[_key_company_type_experience] = self.company_type_experience[_key_company_type_experience].to_dict()
            _dict['companyTypeExperience'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in education (dict)
        _field_dict = {}
        if self.education:
            for _key_education in self.education:
                if self.education[_key_education]:
                    _field_dict[_key_education] = self.education[_key_education].to_dict()
            _dict['education'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in experience_and_seniority (dict)
        _field_dict = {}
        if self.experience_and_seniority:
            for _key_experience_and_seniority in self.experience_and_seniority:
                if self.experience_and_seniority[_key_experience_and_seniority]:
                    _field_dict[_key_experience_and_seniority] = self.experience_and_seniority[_key_experience_and_seniority].to_dict()
            _dict['experienceAndSeniority'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in industry_experience (dict)
        _field_dict = {}
        if self.industry_experience:
            for _key_industry_experience in self.industry_experience:
                if self.industry_experience[_key_industry_experience]:
                    _field_dict[_key_industry_experience] = self.industry_experience[_key_industry_experience].to_dict()
            _dict['industryExperience'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in job_positions (dict)
        _field_dict = {}
        if self.job_positions:
            for _key_job_positions in self.job_positions:
                if self.job_positions[_key_job_positions]:
                    _field_dict[_key_job_positions] = self.job_positions[_key_job_positions].to_dict()
            _dict['jobPositions'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in job_tendencies (dict)
        _field_dict = {}
        if self.job_tendencies:
            for _key_job_tendencies in self.job_tendencies:
                if self.job_tendencies[_key_job_tendencies]:
                    _field_dict[_key_job_tendencies] = self.job_tendencies[_key_job_tendencies].to_dict()
            _dict['jobTendencies'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in languages_spoken (dict)
        _field_dict = {}
        if self.languages_spoken:
            for _key_languages_spoken in self.languages_spoken:
                if self.languages_spoken[_key_languages_spoken]:
                    _field_dict[_key_languages_spoken] = self.languages_spoken[_key_languages_spoken].to_dict()
            _dict['languagesSpoken'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in licenses (dict)
        _field_dict = {}
        if self.licenses:
            for _key_licenses in self.licenses:
                if self.licenses[_key_licenses]:
                    _field_dict[_key_licenses] = self.licenses[_key_licenses].to_dict()
            _dict['licenses'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in location_preferences (dict)
        _field_dict = {}
        if self.location_preferences:
            for _key_location_preferences in self.location_preferences:
                if self.location_preferences[_key_location_preferences]:
                    _field_dict[_key_location_preferences] = self.location_preferences[_key_location_preferences].to_dict()
            _dict['locationPreferences'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in personality_and_soft_skills (dict)
        _field_dict = {}
        if self.personality_and_soft_skills:
            for _key_personality_and_soft_skills in self.personality_and_soft_skills:
                if self.personality_and_soft_skills[_key_personality_and_soft_skills]:
                    _field_dict[_key_personality_and_soft_skills] = self.personality_and_soft_skills[_key_personality_and_soft_skills].to_dict()
            _dict['personalityAndSoftSkills'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in salary_expectation (dict)
        _field_dict = {}
        if self.salary_expectation:
            for _key_salary_expectation in self.salary_expectation:
                if self.salary_expectation[_key_salary_expectation]:
                    _field_dict[_key_salary_expectation] = self.salary_expectation[_key_salary_expectation].to_dict()
            _dict['salaryExpectation'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in skills_and_expertise (dict)
        _field_dict = {}
        if self.skills_and_expertise:
            for _key_skills_and_expertise in self.skills_and_expertise:
                if self.skills_and_expertise[_key_skills_and_expertise]:
                    _field_dict[_key_skills_and_expertise] = self.skills_and_expertise[_key_skills_and_expertise].to_dict()
            _dict['skillsAndExpertise'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in work_authorization (dict)
        _field_dict = {}
        if self.work_authorization:
            for _key_work_authorization in self.work_authorization:
                if self.work_authorization[_key_work_authorization]:
                    _field_dict[_key_work_authorization] = self.work_authorization[_key_work_authorization].to_dict()
            _dict['workAuthorization'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in work_preferences (dict)
        _field_dict = {}
        if self.work_preferences:
            for _key_work_preferences in self.work_preferences:
                if self.work_preferences[_key_work_preferences]:
                    _field_dict[_key_work_preferences] = self.work_preferences[_key_work_preferences].to_dict()
            _dict['workPreferences'] = _field_dict
        # set to None if age (nullable) is None
        # and model_fields_set contains the field
        if self.age is None and "age" in self.model_fields_set:
            _dict['age'] = None

        # set to None if gender (nullable) is None
        # and model_fields_set contains the field
        if self.gender is None and "gender" in self.model_fields_set:
            _dict['gender'] = None

        # set to None if source (nullable) is None
        # and model_fields_set contains the field
        if self.source is None and "source" in self.model_fields_set:
            _dict['source'] = None

        # set to None if short_code (nullable) is None
        # and model_fields_set contains the field
        if self.short_code is None and "short_code" in self.model_fields_set:
            _dict['shortCode'] = None

        # set to None if language_code (nullable) is None
        # and model_fields_set contains the field
        if self.language_code is None and "language_code" in self.model_fields_set:
            _dict['languageCode'] = None

        # set to None if recommendation_status_code (nullable) is None
        # and model_fields_set contains the field
        if self.recommendation_status_code is None and "recommendation_status_code" in self.model_fields_set:
            _dict['recommendationStatusCode'] = None

        # set to None if overall_match_rating (nullable) is None
        # and model_fields_set contains the field
        if self.overall_match_rating is None and "overall_match_rating" in self.model_fields_set:
            _dict['overallMatchRating'] = None

        # set to None if prev_overall_match_rating (nullable) is None
        # and model_fields_set contains the field
        if self.prev_overall_match_rating is None and "prev_overall_match_rating" in self.model_fields_set:
            _dict['prevOverallMatchRating'] = None

        # set to None if ttl (nullable) is None
        # and model_fields_set contains the field
        if self.ttl is None and "ttl" in self.model_fields_set:
            _dict['ttl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CandidateAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "email": obj.get("email"),
            "secondaryEmail": obj.get("secondaryEmail"),
            "workEmail": obj.get("workEmail"),
            "phone": obj.get("phone"),
            "workPhone": obj.get("workPhone"),
            "status": obj.get("status"),
            "stage": obj.get("stage"),
            "age": obj.get("age"),
            "gender": obj.get("gender"),
            "source": obj.get("source"),
            "shortCode": obj.get("shortCode"),
            "languageCode": obj.get("languageCode"),
            "recommendationStatusCode": obj.get("recommendationStatusCode"),
            "overallMatchRating": obj.get("overallMatchRating"),
            "prevOverallMatchRating": obj.get("prevOverallMatchRating"),
            "ttl": obj.get("ttl"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None,
            "alumni": TalentAlumniSchema.from_dict(obj["alumni"]) if obj.get("alumni") is not None else None,
            "referral": TalentReferralSchema.from_dict(obj["referral"]) if obj.get("referral") is not None else None,
            "jobPositionTitle": obj.get("jobPositionTitle"),
            "rejectionTicket": obj.get("rejectionTicket"),
            "recommendationStatus": obj.get("recommendationStatus"),
            "overallAssessment": obj.get("overallAssessment"),
            "nextSteps": obj.get("nextSteps"),
            "insightsAndAnalysis": obj.get("insightsAndAnalysis"),
            "keywords": obj.get("keywords"),
            "availability": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["availability"].items()
            )
            if obj.get("availability") is not None
            else None,
            "certifications": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["certifications"].items()
            )
            if obj.get("certifications") is not None
            else None,
            "companyTypeExperience": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["companyTypeExperience"].items()
            )
            if obj.get("companyTypeExperience") is not None
            else None,
            "education": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["education"].items()
            )
            if obj.get("education") is not None
            else None,
            "experienceAndSeniority": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["experienceAndSeniority"].items()
            )
            if obj.get("experienceAndSeniority") is not None
            else None,
            "industryExperience": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["industryExperience"].items()
            )
            if obj.get("industryExperience") is not None
            else None,
            "jobPositions": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["jobPositions"].items()
            )
            if obj.get("jobPositions") is not None
            else None,
            "jobTendencies": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["jobTendencies"].items()
            )
            if obj.get("jobTendencies") is not None
            else None,
            "languagesSpoken": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["languagesSpoken"].items()
            )
            if obj.get("languagesSpoken") is not None
            else None,
            "licenses": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["licenses"].items()
            )
            if obj.get("licenses") is not None
            else None,
            "locationPreferences": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["locationPreferences"].items()
            )
            if obj.get("locationPreferences") is not None
            else None,
            "personalityAndSoftSkills": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["personalityAndSoftSkills"].items()
            )
            if obj.get("personalityAndSoftSkills") is not None
            else None,
            "salaryExpectation": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["salaryExpectation"].items()
            )
            if obj.get("salaryExpectation") is not None
            else None,
            "skillsAndExpertise": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["skillsAndExpertise"].items()
            )
            if obj.get("skillsAndExpertise") is not None
            else None,
            "workAuthorization": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["workAuthorization"].items()
            )
            if obj.get("workAuthorization") is not None
            else None,
            "workPreferences": dict(
                (_k, CandidateCriteriaSchema.from_dict(_v))
                for _k, _v in obj["workPreferences"].items()
            )
            if obj.get("workPreferences") is not None
            else None
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema
from smartytalent_client.models.talent_alumni_schema import TalentAlumniSchema
from smartytalent_client.models.talent_attributes_desired_contract_length_schema import TalentAttributesDesiredContractLengthSchema
from smartytalent_client.models.talent_attributes_desired_employment_type_schema import TalentAttributesDesiredEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_desired_role_schema import TalentAttributesDesiredRoleSchema
from smartytalent_client.models.talent_attributes_employment_type_schema import TalentAttributesEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_social_link_schema import TalentAttributesSocialLinkSchema
from smartytalent_client.models.talent_availability_received_criteria_schema import TalentAvailabilityReceivedCriteriaSchema
from smartytalent_client.models.talent_received_criteria_schema import TalentReceivedCriteriaSchema
from smartytalent_client.models.talent_referral_schema import TalentReferralSchema
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class TalentAttributesSchema(BaseModel):
    """
    TalentAttributesSchema
    """ # noqa: E501
    status: Optional[StrictStr] = None
    name: StrictStr
    email: StrictStr
    secondary_email: Optional[StrictStr] = Field(default=None, alias="secondaryEmail")
    timestamps: Optional[ResourceTimestampsSchema] = None
    work_email: Optional[StrictStr] = Field(default=None, alias="workEmail")
    phone: Optional[StrictStr] = None
    work_phone: Optional[StrictStr] = Field(default=None, alias="workPhone")
    profile_picture_url: Optional[StrictStr] = Field(default=None, alias="profilePictureUrl")
    availability: Optional[Dict[str, TalentAvailabilityReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed availability criteria. Keys are locale codes (e.g. en-US, pl-PL).")
    desired_contract_length: Optional[TalentAttributesDesiredContractLengthSchema] = Field(default=None, alias="desiredContractLength")
    employment_type: Optional[TalentAttributesEmploymentTypeSchema] = Field(default=None, alias="employmentType")
    experience_and_seniority: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed experience and seniority criteria.", alias="experienceAndSeniority")
    break_reason: Optional[StrictStr] = Field(default=None, alias="breakReason")
    quick_insights: Optional[Dict[str, StrictStr]] = Field(default=None, description="Language-keyed quick insights. Keys are locale codes (e.g. en-US, pl-PL).", alias="quickInsights")
    languages_spoken: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed languages spoken criteria.", alias="languagesSpoken")
    social_links: Optional[List[TalentAttributesSocialLinkSchema]] = Field(default=None, alias="socialLinks")
    desired_employment_type: Optional[List[TalentAttributesDesiredEmploymentTypeSchema]] = Field(default=None, alias="desiredEmploymentType")
    desired_role: Optional[List[TalentAttributesDesiredRoleSchema]] = Field(default=None, alias="desiredRole")
    work_preferences: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed work preferences criteria.", alias="workPreferences")
    location_preferences: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed location preferences criteria.", alias="locationPreferences")
    work_authorization: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed work authorization criteria.", alias="workAuthorization")
    skills_and_expertise: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed skills and expertise criteria.", alias="skillsAndExpertise")
    certifications: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed certifications criteria.")
    licenses: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed licenses criteria.")
    professional_experience: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed professional experience criteria.", alias="professionalExperience")
    industry_experience: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed industry experience criteria.", alias="industryExperience")
    company_type_experience: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed company type experience criteria.", alias="companyTypeExperience")
    job_positions: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed job positions criteria.", alias="jobPositions")
    job_tendencies: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed job tendencies criteria.", alias="jobTendencies")
    education: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed education criteria.")
    projects_and_achievements: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed projects and achievements criteria.", alias="projectsAndAchievements")
    personality_and_soft_skills: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed personality and soft skills criteria.", alias="personalityAndSoftSkills")
    hobbies_and_interests: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="Language-keyed hobbies and interests. Keys are locale codes (e.g. en-US, pl-PL).", alias="hobbiesAndInterests")
    references: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed references criteria.")
    keywords: Optional[Dict[str, List[StrictStr]]] = Field(default=None, description="Language-keyed keywords. Keys are locale codes (e.g. en-US, pl-PL).")
    performance_reviews: Optional[List[Dict[str, Any]]] = Field(default=None, alias="performanceReviews")
    personality_tests: Optional[Dict[str, Any]] = Field(default=None, alias="personalityTests")
    salary_expectation: Optional[Dict[str, TalentReceivedCriteriaSchema]] = Field(default=None, description="Language-keyed salary expectation criteria.", alias="salaryExpectation")
    relocation_willingness: Optional[StrictBool] = Field(default=None, alias="relocationWillingness")
    requires_sponsorship: Optional[StrictBool] = Field(default=None, alias="requiresSponsorship")
    career_break: Optional[StrictBool] = Field(default=None, alias="careerBreak")
    is_talent_pool: Optional[StrictBool] = Field(default=None, alias="isTalentPool")
    ttl: Optional[StrictStr] = None
    alumni: Optional[TalentAlumniSchema] = None
    referral: Optional[TalentReferralSchema] = None
    age: Optional[StrictStr] = None
    gender: Optional[StrictStr] = None
    settings: Optional[Dict[str, Any]] = None
    short_code: Optional[StrictStr] = Field(default=None, alias="shortCode")
    source: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["status", "name", "email", "secondaryEmail", "timestamps", "workEmail", "phone", "workPhone", "profilePictureUrl", "availability", "desiredContractLength", "employmentType", "experienceAndSeniority", "breakReason", "quickInsights", "languagesSpoken", "socialLinks", "desiredEmploymentType", "desiredRole", "workPreferences", "locationPreferences", "workAuthorization", "skillsAndExpertise", "certifications", "licenses", "professionalExperience", "industryExperience", "companyTypeExperience", "jobPositions", "jobTendencies", "education", "projectsAndAchievements", "personalityAndSoftSkills", "hobbiesAndInterests", "references", "keywords", "performanceReviews", "personalityTests", "salaryExpectation", "relocationWillingness", "requiresSponsorship", "careerBreak", "isTalentPool", "ttl", "alumni", "referral", "age", "gender", "settings", "shortCode", "source"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['active', 'inactive', 'pending', 'archived', 'failed']):
            raise ValueError("must be one of enum values ('active', 'inactive', 'pending', 'archived', 'failed')")
        return value

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TalentAttributesSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict['timestamps'] = self.timestamps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in availability (dict)
        _field_dict = {}
        if self.availability:
            for _key_availability in self.availability:
                if self.availability[_key_availability]:
                    _field_dict[_key_availability] = self.availability[_key_availability].to_dict()
            _dict['availability'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of desired_contract_length
        if self.desired_contract_length:
            _dict['desiredContractLength'] = self.desired_contract_length.to_dict()
        # override the default output from pydantic by calling `to_dict()` of employment_type
        if self.employment_type:
            _dict['employmentType'] = self.employment_type.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each value in experience_and_seniority (dict)
        _field_dict = {}
        if self.experience_and_seniority:
            for _key_experience_and_seniority in self.experience_and_seniority:
                if self.experience_and_seniority[_key_experience_and_seniority]:
                    _field_dict[_key_experience_and_seniority] = self.experience_and_seniority[_key_experience_and_seniority].to_dict()
            _dict['experienceAndSeniority'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in languages_spoken (dict)
        _field_dict = {}
        if self.languages_spoken:
            for _key_languages_spoken in self.languages_spoken:
                if self.languages_spoken[_key_languages_spoken]:
                    _field_dict[_key_languages_spoken] = self.languages_spoken[_key_languages_spoken].to_dict()
            _dict['languagesSpoken'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each item in social_links (list)
        _items = []
        if self.social_links:
            for _item_social_links in self.social_links:
                if _item_social_links:
                    _items.append(_item_social_links.to_dict())
            _dict['socialLinks'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in desired_employment_type (list)
        _items = []
        if self.desired_employment_type:
            for _item_desired_employment_type in self.desired_employment_type:
                if _item_desired_employment_type:
                    _items.append(_item_desired_employment_type.to_dict())
            _dict['desiredEmploymentType'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in desired_role (list)
        _items = []
        if self.desired_role:
            for _item_desired_role in self.desired_role:
                if _item_desired_role:
                    _items.append(_item_desired_role.to_dict())
            _dict['desiredRole'] = _items
        # override the default output from pydantic by calling `to_dict()` of each value in work_preferences (dict)
        _field_dict = {}
        if self.work_preferences:
            for _key_work_preferences in self.work_preferences:
                if self.work_preferences[_key_work_preferences]:
                    _field_dict[_key_work_preferences] = self.work_preferences[_key_work_preferences].to_dict()
            _dict['workPreferences'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in location_preferences (dict)
        _field_dict = {}
        if self.location_preferences:
            for _key_location_preferences in self.location_preferences:
                if self.location_preferences[_key_location_preferences]:
                    _field_dict[_key_location_preferences] = self.location_preferences[_key_location_preferences].to_dict()
            _dict['locationPreferences'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in work_authorization (dict)
        _field_dict = {}
        if self.work_authorization:
            for _key_work_authorization in self.work_authorization:
                if self.work_authorization[_key_work_authorization]:
                    _field_dict[_key_work_authorization] = self.work_authorization[_key_work_authorization].to_dict()
            _dict['workAuthorization'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in skills_and_expertise (dict)
        _field_dict = {}
        if self.skills_and_expertise:
            for _key_skills_and_expertise in self.skills_and_expertise:
                if self.skills_and_expertise[_key_skills_and_expertise]:
                    _field_dict[_key_skills_and_expertise] = self.skills_and_expertise[_key_skills_and_expertise].to_dict()
            _dict['skillsAndExpertise'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in certifications (dict)
        _field_dict = {}
        if self.certifications:
            for _key_certifications in self.certifications:
                if self.certifications[_key_certifications]:
                    _field_dict[_key_certifications] = self.certifications[_key_certifications].to_dict()
            _dict['certifications'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in licenses (dict)
        _field_dict = {}
        if self.licenses:
            for _key_licenses in self.licenses:
                if self.licenses[_key_licenses]:
                    _field_dict[_key_licenses] = self.licenses[_key_licenses].to_dict()
            _dict['licenses'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in professional_experience (dict)
        _field_dict = {}
        if self.professional_experience:
            for _key_professional_experience in self.professional_experience:
                if self.professional_experience[_key_professional_experience]:
                    _field_dict[_key_professional_experience] = self.professional_experience[_key_professional_experience].to_dict()
            _dict['professionalExperience'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in industry_experience (dict)
        _field_dict = {}
        if self.industry_experience:
            for _key_industry_experience in self.industry_experience:
                if self.industry_experience[_key_industry_experience]:
                    _field_dict[_key_industry_experience] = self.industry_experience[_key_industry_experience].to_dict()
            _dict['industryExperience'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in company_type_experience (dict)
        _field_dict = {}
        if self.company_type_experience:
            for _key_company_type_experience in self.company_type_experience:
                if self.company_type_experience[_key_company_type_experience]:
                    _field_dict[_key_company_type_experience] = self.company_type_experience[_key_company_type_experience].to_dict()
            _dict['companyTypeExperience'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in job_positions (dict)
        _field_dict = {}
        if self.job_positions:
            for _key_job_positions in self.job_positions:
                if self.job_positions[_key_job_positions]:
                    _field_dict[_key_job_positions] = self.job_positions[_key_job_positions].to_dict()
            _dict['jobPositions'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in job_tendencies (dict)
        _field_dict = {}
        if self.job_tendencies:
            for _key_job_tendencies in self.job_tendencies:
                if self.job_tendencies[_key_job_tendencies]:
                    _field_dict[_key_job_tendencies] = self.job_tendencies[_key_job_tendencies].to_dict()
            _dict['jobTendencies'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in education (dict)
        _field_dict = {}
        if self.education:
            for _key_education in self.education:
                if self.education[_key_education]:
                    _field_dict[_key_education] = self.education[_key_education].to_dict()
            _dict['education'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in projects_and_achievements (dict)
        _field_dict = {}
        if self.projects_and_achievements:
            for _key_projects_and_achievements in self.projects_and_achievements:
                if self.projects_and_achievements[_key_projects_and_achievements]:
                    _field_dict[_key_projects_and_achievements] = self.projects_and_achievements[_key_projects_and_achievements].to_dict()
            _dict['projectsAndAchievements'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in personality_and_soft_skills (dict)
        _field_dict = {}
        if self.personality_and_soft_skills:
            for _key_personality_and_soft_skills in self.personality_and_soft_skills:
                if self.personality_and_soft_skills[_key_personality_and_soft_skills]:
                    _field_dict[_key_personality_and_soft_skills] = self.personality_and_soft_skills[_key_personality_and_soft_skills].to_dict()
            _dict['personalityAndSoftSkills'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in references (dict)
        _field_dict = {}
        if self.references:
            for _key_references in self.references:
                if self.references[_key_references]:
                    _field_dict[_key_references] = self.references[_key_references].to_dict()
            _dict['references'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in salary_expectation (dict)
        _field_dict = {}
        if self.salary_expectation:
            for _key_salary_expectation in self.salary_expectation:
                if self.salary_expectation[_key_salary_expectation]:
                    _field_dict[_key_salary_expectation] = self.salary_expectation[_key_salary_expectation].to_dict()
            _dict['salaryExpectation'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of alumni
        if self.alumni:
            _dict['alumni'] = self.alumni.to_dict()
        # override the default output from pydantic by calling `to_dict()` of referral
        if self.referral:
            _dict['referral'] = self.referral.to_dict()
        # set to None if profile_picture_url (nullable) is None
        # and model_fields_set contains the field
        if self.profile_picture_url is None and "profile_picture_url" in self.model_fields_set:
            _dict['profilePictureUrl'] = None

        # set to None if ttl (nullable) is None
        # and model_fields_set contains the field
        if self.ttl is None and "ttl" in self.model_fields_set:
            _dict['ttl'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TalentAttributesSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "status": obj.get("status"),
            "name": obj.get("name"),
            "email": obj.get("email"),
            "secondaryEmail": obj.get("secondaryEmail"),
            "timestamps": ResourceTimestampsSchema.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None,
            "workEmail": obj.get("workEmail"),
            "phone": obj.get("phone"),
            "workPhone": obj.get("workPhone"),
            "profilePictureUrl": obj.get("profilePictureUrl"),
            "availability": dict(
                (_k, TalentAvailabilityReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["availability"].items()
            )
            if obj.get("availability") is not None
            else None,
            "desiredContractLength": TalentAttributesDesiredContractLengthSchema.from_dict(obj["desiredContractLength"]) if obj.get("desiredContractLength") is not None else None,
            "employmentType": TalentAttributesEmploymentTypeSchema.from_dict(obj["employmentType"]) if obj.get("employmentType") is not None else None,
            "experienceAndSeniority": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["experienceAndSeniority"].items()
            )
            if obj.get("experienceAndSeniority") is not None
            else None,
            "breakReason": obj.get("breakReason"),
            "quickInsights": obj.get("quickInsights"),
            "languagesSpoken": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["languagesSpoken"].items()
            )
            if obj.get("languagesSpoken") is not None
            else None,
            "socialLinks": [TalentAttributesSocialLinkSchema.from_dict(_item) for _item in obj["socialLinks"]] if obj.get("socialLinks") is not None else None,
            "desiredEmploymentType": [TalentAttributesDesiredEmploymentTypeSchema.from_dict(_item) for _item in obj["desiredEmploymentType"]] if obj.get("desiredEmploymentType") is not None else None,
            "desiredRole": [TalentAttributesDesiredRoleSchema.from_dict(_item) for _item in obj["desiredRole"]] if obj.get("desiredRole") is not None else None,
            "workPreferences": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["workPreferences"].items()
            )
            if obj.get("workPreferences") is not None
            else None,
            "locationPreferences": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["locationPreferences"].items()
            )
            if obj.get("locationPreferences") is not None
            else None,
            "workAuthorization": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["workAuthorization"].items()
            )
            if obj.get("workAuthorization") is not None
            else None,
            "skillsAndExpertise": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["skillsAndExpertise"].items()
            )
            if obj.get("skillsAndExpertise") is not None
            else None,
            "certifications": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["certifications"].items()
            )
            if obj.get("certifications") is not None
            else None,
            "licenses": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["licenses"].items()
            )
            if obj.get("licenses") is not None
            else None,
            "professionalExperience": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["professionalExperience"].items()
            )
            if obj.get("professionalExperience") is not None
            else None,
            "industryExperience": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["industryExperience"].items()
            )
            if obj.get("industryExperience") is not None
            else None,
            "companyTypeExperience": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["companyTypeExperience"].items()
            )
            if obj.get("companyTypeExperience") is not None
            else None,
            "jobPositions": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["jobPositions"].items()
            )
            if obj.get("jobPositions") is not None
            else None,
            "jobTendencies": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["jobTendencies"].items()
            )
            if obj.get("jobTendencies") is not None
            else None,
            "education": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["education"].items()
            )
            if obj.get("education") is not None
            else None,
            "projectsAndAchievements": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["projectsAndAchievements"].items()
            )
            if obj.get("projectsAndAchievements") is not None
            else None,
            "personalityAndSoftSkills": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["personalityAndSoftSkills"].items()
            )
            if obj.get("personalityAndSoftSkills") is not None
            else None,
            "hobbiesAndInterests": obj.get("hobbiesAndInterests"),
            "references": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["references"].items()
            )
            if obj.get("references") is not None
            else None,
            "keywords": obj.get("keywords"),
            "performanceReviews": obj.get("performanceReviews"),
            "personalityTests": obj.get("personalityTests"),
            "salaryExpectation": dict(
                (_k, TalentReceivedCriteriaSchema.from_dict(_v))
                for _k, _v in obj["salaryExpectation"].items()
            )
            if obj.get("salaryExpectation") is not None
            else None,
            "relocationWillingness": obj.get("relocationWillingness"),
            "requiresSponsorship": obj.get("requiresSponsorship"),
            "careerBreak": obj.get("careerBreak"),
            "isTalentPool": obj.get("isTalentPool"),
            "ttl": obj.get("ttl"),
            "alumni": TalentAlumniSchema.from_dict(obj["alumni"]) if obj.get("alumni") is not None else None,
            "referral": TalentReferralSchema.from_dict(obj["referral"]) if obj.get("referral") is not None else None,
            "age": obj.get("age"),
            "gender": obj.get("gender"),
            "settings": obj.get("settings"),
            "shortCode": obj.get("shortCode"),
            "source": obj.get("source")
        })
        return _obj





# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.api.translations_api import TranslationsApi


class TestTranslationsApi(unittest.TestCase):
    """TranslationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TranslationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_translation(self) -> None:
        """Test case for create_translation

        Create Translation
        """
        pass

    def test_delete_translation(self) -> None:
        """Test case for delete_translation

        Delete Translation
        """
        pass

    def test_list_translations(self) -> None:
        """Test case for list_translations

        List Translations
        """
        pass

    def test_show_translation(self) -> None:
        """Test case for show_translation

        Show Translation
        """
        pass

    def test_translation_options(self) -> None:
        """Test case for translation_options

        Translation Options
        """
        pass

    def test_translations_options(self) -> None:
        """Test case for translations_options

        Translations Options
        """
        pass

    def test_update_translation(self) -> None:
        """Test case for update_translation

        Update Translation
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.update_tenant_request_body_data import UpdateTenantRequestBodyData

class TestUpdateTenantRequestBodyData(unittest.TestCase):
    """UpdateTenantRequestBodyData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpdateTenantRequestBodyData:
        """Test UpdateTenantRequestBodyData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpdateTenantRequestBodyData`
        """
        model = UpdateTenantRequestBodyData()
        if include_optional:
            return UpdateTenantRequestBodyData(
                type = 'tenants',
                id = '',
                attributes = smartytalent_client.models.tenant_attributes_schema.TenantAttributesSchema(
                    name = '', 
                    username = '', 
                    email = '01234', 
                    status = '', 
                    short_code = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    phone = '', 
                    address = smartytalent_client.models.tenant_attributes_address_schema.TenantAttributesAddressSchema(
                        county = '', 
                        country = '', 
                        city = '', 
                        postalcode = '', 
                        street = '', ), 
                    settings = smartytalent_client.models.tenant_attributes_settings_schema.TenantAttributesSettingsSchema(
                        ad = smartytalent_client.models.ad.ad(), 
                        conversation = smartytalent_client.models.conversation.conversation(), 
                        report = smartytalent_client.models.report.report(), 
                        email = smartytalent_client.models.email.email(), 
                        language = '', 
                        calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                            enabled = True, 
                            twilio_subaccount_sid = '', 
                            twilio_phone_number = '', 
                            twilio_phone_sid = '', 
                            provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                    plan = '0', 
                    active_languages = [
                        'ae-IO'
                        ], 
                    trial_expiry_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    timezone = '', 
                    logo_url = '', 
                    boe_phone = '', 
                    boe_email = '', )
            )
        else:
            return UpdateTenantRequestBodyData(
                type = 'tenants',
                id = '',
                attributes = smartytalent_client.models.tenant_attributes_schema.TenantAttributesSchema(
                    name = '', 
                    username = '', 
                    email = '01234', 
                    status = '', 
                    short_code = '', 
                    timestamps = smartytalent_client.models.resource_timestamps_schema.ResourceTimestampsSchema(
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                    phone = '', 
                    address = smartytalent_client.models.tenant_attributes_address_schema.TenantAttributesAddressSchema(
                        county = '', 
                        country = '', 
                        city = '', 
                        postalcode = '', 
                        street = '', ), 
                    settings = smartytalent_client.models.tenant_attributes_settings_schema.TenantAttributesSettingsSchema(
                        ad = smartytalent_client.models.ad.ad(), 
                        conversation = smartytalent_client.models.conversation.conversation(), 
                        report = smartytalent_client.models.report.report(), 
                        email = smartytalent_client.models.email.email(), 
                        language = '', 
                        calling = smartytalent_client.models.tenant_attributes_settings_schema_calling.TenantAttributesSettingsSchema_calling(
                            enabled = True, 
                            twilio_subaccount_sid = '', 
                            twilio_phone_number = '', 
                            twilio_phone_sid = '', 
                            provisioned_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), ), 
                    plan = '0', 
                    active_languages = [
                        'ae-IO'
                        ], 
                    trial_expiry_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    timezone = '', 
                    logo_url = '', 
                    boe_phone = '', 
                    boe_email = '', ),
        )
        """

    def testUpdateTenantRequestBodyData(self):
        """Test UpdateTenantRequestBodyData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from smartytalent_client.models.persona_relationships_translations_schema import PersonaRelationshipsTranslationsSchema

class TestPersonaRelationshipsTranslationsSchema(unittest.TestCase):
    """PersonaRelationshipsTranslationsSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PersonaRelationshipsTranslationsSchema:
        """Test PersonaRelationshipsTranslationsSchema
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PersonaRelationshipsTranslationsSchema`
        """
        model = PersonaRelationshipsTranslationsSchema()
        if include_optional:
            return PersonaRelationshipsTranslationsSchema(
                data = [
                    smartytalent_client.models.persona_relationships_translations_data_schema.PersonaRelationshipsTranslationsDataSchema(
                        type = 'translations', 
                        id = '655cde5c9931802df628f3d2de8ca681-2', )
                    ]
            )
        else:
            return PersonaRelationshipsTranslationsSchema(
        )
        """

    def testPersonaRelationshipsTranslationsSchema(self):
        """Test PersonaRelationshipsTranslationsSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    SmartyMeet Dev03 API REST

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0.1
    Contact: developer@smartymeet.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "ActionsApi",
    "AdsApi",
    "ApikeysApi",
    "AssessmentsApi",
    "BrowsersApi",
    "CallsApi",
    "CandidatesApi",
    "ChatsApi",
    "ConversationsApi",
    "EmailsApi",
    "FilesApi",
    "FindersApi",
    "FormsApi",
    "JobsApi",
    "LinksApi",
    "MeetingsApi",
    "NotesApi",
    "NotificationsApi",
    "OperationsApi",
    "PersonasApi",
    "ReportsApi",
    "RolesApi",
    "RunsApi",
    "TalentsApi",
    "TenantsApi",
    "TimelinesApi",
    "TranslationsApi",
    "TriggersApi",
    "UsersApi",
    "WebhooksApi",
    "WorkflowsApi",
    "DefaultApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AdAttributesSchema",
    "AdAttributesSchemaImagesInner",
    "AdRelationshipsJobDataSchema",
    "AdRelationshipsJobSchema",
    "AdRelationshipsSchema",
    "AdResourceSchema",
    "AdSchema",
    "AdsSchema",
    "ApikeyAttributesSchema",
    "ApikeyRelationshipsSchema",
    "ApikeyRelationshipsUserDataSchema",
    "ApikeyRelationshipsUserSchema",
    "ApikeyResourceSchema",
    "ApikeySchema",
    "ApikeysSchema",
    "AssessmentAttributesSchema",
    "AssessmentRelationshipsCandidateDataSchema",
    "AssessmentRelationshipsCandidateSchema",
    "AssessmentRelationshipsJobDataSchema",
    "AssessmentRelationshipsJobSchema",
    "AssessmentRelationshipsSchema",
    "AssessmentResourceSchema",
    "AssessmentSchema",
    "AssessmentsSchema",
    "BrowserAttributesSchema",
    "BrowserRelationshipsSchema",
    "BrowserRelationshipsTranslationsDataSchema",
    "BrowserRelationshipsTranslationsSchema",
    "BrowserResourceSchema",
    "BrowserSchema",
    "BrowsersSchema",
    "CallAttributesSchema",
    "CallRelationshipsSchema",
    "CallRelationshipsTranslationsDataSchema",
    "CallRelationshipsTranslationsSchema",
    "CallResourceSchema",
    "CallSchema",
    "CallsSchema",
    "CandidateAttributesSchema",
    "CandidateCriteriaSchema",
    "CandidateRelationshipsJobDataSchema",
    "CandidateRelationshipsJobSchema",
    "CandidateRelationshipsOperationsDataSchema",
    "CandidateRelationshipsOperationsSchema",
    "CandidateRelationshipsSchema",
    "CandidateRelationshipsTalentDataSchema",
    "CandidateRelationshipsTalentSchema",
    "CandidateRelationshipsTranslationsDataSchema",
    "CandidateRelationshipsTranslationsSchema",
    "CandidateResourceSchema",
    "CandidateSchema",
    "CandidatesSchema",
    "ChatAttributesSchema",
    "ChatRelationshipsSchema",
    "ChatRelationshipsTranslationsDataSchema",
    "ChatRelationshipsTranslationsSchema",
    "ChatResourceSchema",
    "ChatSchema",
    "ChatsSchema",
    "ConversationAttributesSchema",
    "ConversationRelationshipsCandidateDataSchema",
    "ConversationRelationshipsCandidateSchema",
    "ConversationRelationshipsSchema",
    "ConversationResourceSchema",
    "ConversationSchema",
    "ConversationsSchema",
    "CreateAdRequestBody",
    "CreateAdRequestBodyData",
    "CreateApikeyRequestBody",
    "CreateApikeyRequestBodyData",
    "CreateAssessmentRequestBody",
    "CreateAssessmentRequestBodyData",
    "CreateBrowserRequestBody",
    "CreateBrowserRequestBodyData",
    "CreateCallRequestBody",
    "CreateCallRequestBodyData",
    "CreateCandidateRequestBody",
    "CreateCandidateRequestBodyData",
    "CreateChatRequestBody",
    "CreateChatRequestBodyData",
    "CreateConversationRequestBody",
    "CreateConversationRequestBodyData",
    "CreateEmailRequestBody",
    "CreateEmailRequestBodyData",
    "CreateFileRequestBody",
    "CreateFileRequestBodyData",
    "CreateFinderRequestBody",
    "CreateFinderRequestBodyData",
    "CreateFormRequestBody",
    "CreateFormRequestBodyData",
    "CreateJobRequestBody",
    "CreateJobRequestBodyData",
    "CreateLinkRequestBody",
    "CreateLinkRequestBodyData",
    "CreateMeetingAiSessionRequestBody",
    "CreateMeetingAiSessionRequestBodyData",
    "CreateMeetingAttendeeRequestBody",
    "CreateMeetingAttendeeRequestBodyData",
    "CreateMeetingRequestBody",
    "CreateMeetingRequestBodyData",
    "CreateNoteRequestBody",
    "CreateNoteRequestBodyData",
    "CreateNotificationRequestBody",
    "CreateNotificationRequestBodyData",
    "CreateOperationRequestBody",
    "CreateOperationRequestBodyData",
    "CreatePersonaRequestBody",
    "CreatePersonaRequestBodyData",
    "CreateReportRequestBody",
    "CreateReportRequestBodyData",
    "CreateRoleRequestBody",
    "CreateRoleRequestBodyData",
    "CreateTalentRequestBody",
    "CreateTalentRequestBodyData",
    "CreateTenantRequestBody",
    "CreateTenantRequestBodyData",
    "CreateTenantUploadRequestBody",
    "CreateTenantUploadRequestBodyData",
    "CreateTenantUploadRequestBodyDataAttributes",
    "CreateTranslationRequestBody",
    "CreateTranslationRequestBodyData",
    "CreateUserRequestBody",
    "CreateUserRequestBodyData",
    "CreateUserUploadRequestBody",
    "CreateUserUploadRequestBodyData",
    "CreateUserUploadRequestBodyDataAttributes",
    "CreateWebhookRequestBody",
    "CreateWebhookRequestBodyData",
    "EmailAttributesSchema",
    "EmailRelationshipsCandidateDataSchema",
    "EmailRelationshipsCandidateSchema",
    "EmailRelationshipsOperationDataSchema",
    "EmailRelationshipsOperationSchema",
    "EmailRelationshipsReportDataSchema",
    "EmailRelationshipsReportSchema",
    "EmailRelationshipsSchema",
    "EmailRelationshipsTranslationsDataSchema",
    "EmailRelationshipsTranslationsSchema",
    "EmailResourceSchema",
    "EmailSchema",
    "EmailsSchema",
    "ErrorObjectSchema",
    "ErrorSchema",
    "FileAttributesSchema",
    "FileRelationshipsLinkDataSchema",
    "FileRelationshipsLinkSchema",
    "FileRelationshipsSchema",
    "FileResourceSchema",
    "FileSchema",
    "FilesSchema",
    "FinderAttributesSchema",
    "FinderRelationshipsCandidatesDataSchema",
    "FinderRelationshipsCandidatesSchema",
    "FinderRelationshipsJobsDataSchema",
    "FinderRelationshipsJobsSchema",
    "FinderRelationshipsSchema",
    "FinderRelationshipsTalentsDataSchema",
    "FinderRelationshipsTalentsSchema",
    "FinderRelationshipsUsersDataSchema",
    "FinderRelationshipsUsersSchema",
    "FinderResourceSchema",
    "FinderSchema",
    "FindersSchema",
    "FormAttributesSchema",
    "FormRelationshipsSchema",
    "FormRelationshipsTranslationsDataSchema",
    "FormRelationshipsTranslationsSchema",
    "FormResourceSchema",
    "FormSchema",
    "FormsSchema",
    "JobAttributesLocationItemSchema",
    "JobAttributesOrganizationAddressSchema",
    "JobAttributesOrganizationSchema",
    "JobAttributesSchema",
    "JobAttributesSettingsConversationCandidateInterviewSchema",
    "JobAttributesSettingsConversationEmailContactSchema",
    "JobAttributesSettingsConversationEmailDelaysSchema",
    "JobAttributesSettingsConversationEmailSchema",
    "JobAttributesSettingsConversationPersonaInterviewSchema",
    "JobAttributesSettingsConversationSchema",
    "JobAttributesSettingsCriteriasSchema",
    "JobAttributesSettingsOperationSchema",
    "JobAttributesSettingsPersonaSchema",
    "JobAttributesSettingsSchema",
    "JobAttributesSiteItemSchema",
    "JobCriteriaSchema",
    "JobRelationshipsCandidatesDataSchema",
    "JobRelationshipsCandidatesSchema",
    "JobRelationshipsConversationsDataSchema",
    "JobRelationshipsConversationsSchema",
    "JobRelationshipsOperationsDataSchema",
    "JobRelationshipsOperationsSchema",
    "JobRelationshipsPersonasDataSchema",
    "JobRelationshipsPersonasSchema",
    "JobRelationshipsSchema",
    "JobRelationshipsTranslationsDataSchema",
    "JobRelationshipsTranslationsSchema",
    "JobResourceSchema",
    "JobSchema",
    "JobsSchema",
    "LinkAttributesSchema",
    "LinkRelationshipsFileDataSchema",
    "LinkRelationshipsFileSchema",
    "LinkRelationshipsSchema",
    "LinkResourceSchema",
    "LinkSchema",
    "LinksSchema",
    "ListCandidateJobsRelationship",
    "ListCandidateTalentsRelationship",
    "ListJobCandidatesRelationship",
    "ListRoleUsersRelationship",
    "ListTalentCandidatesRelationship",
    "ListUserApikeysRelationship",
    "ListUserJobsRelationship",
    "ListUserRolesRelationship",
    "MeetingAiSessionAttributesSchema",
    "MeetingAiSessionAttributesSchemaRealtimeSession",
    "MeetingAiSessionResourceSchema",
    "MeetingAiSessionSchema",
    "MeetingAiSessionSettingsSchema",
    "MeetingAttendeeAttributesSchema",
    "MeetingAttendeeResourceSchema",
    "MeetingAttendeeResourceSchemaAllOfRelationships",
    "MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting",
    "MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData",
    "MeetingAttendeeResponseAttributesSchema",
    "MeetingAttendeeSchema",
    "MeetingAttributesSchema",
    "MeetingLobbyAttributesSchema",
    "MeetingLobbyResourceSchema",
    "MeetingLobbySchema",
    "MeetingRelationshipsParticipantsDataSchema",
    "MeetingRelationshipsParticipantsSchema",
    "MeetingRelationshipsSchema",
    "MeetingResourceSchema",
    "MeetingSchema",
    "MeetingTranscriptionAttributesSchema",
    "MeetingTranscriptionRequestBody",
    "MeetingTranscriptionRequestBodyData",
    "MeetingTranscriptionSchema",
    "MeetingTranscriptionSchemaData",
    "MeetingTranscriptionSettingsSchema",
    "MeetingsSchema",
    "NoteAttributesSchema",
    "NoteRelationshipsCandidateDataSchema",
    "NoteRelationshipsCandidateSchema",
    "NoteRelationshipsOperationDataSchema",
    "NoteRelationshipsOperationSchema",
    "NoteRelationshipsReportDataSchema",
    "NoteRelationshipsReportSchema",
    "NoteRelationshipsSchema",
    "NoteRelationshipsTranslationsDataSchema",
    "NoteRelationshipsTranslationsSchema",
    "NoteResourceSchema",
    "NoteSchema",
    "NotesSchema",
    "NotificationAttributesSchema",
    "NotificationRelationshipsSchema",
    "NotificationRelationshipsSchemaUsers",
    "NotificationRelationshipsSchemaUsersDataInner",
    "NotificationResourceSchema",
    "NotificationSchema",
    "NotificationsSchema",
    "OperationAttributesSchema",
    "OperationRelationshipsCandidateDataSchema",
    "OperationRelationshipsCandidateSchema",
    "OperationRelationshipsJobDataSchema",
    "OperationRelationshipsJobSchema",
    "OperationRelationshipsSchema",
    "OperationResourceSchema",
    "OperationSchema",
    "OperationsSchema",
    "PersonaAttributesSchema",
    "PersonaRelationshipsCandidatesDataSchema",
    "PersonaRelationshipsCandidatesSchema",
    "PersonaRelationshipsOperationsDataSchema",
    "PersonaRelationshipsOperationsSchema",
    "PersonaRelationshipsSchema",
    "PersonaRelationshipsTalentsDataSchema",
    "PersonaRelationshipsTalentsSchema",
    "PersonaRelationshipsTranslationsDataSchema",
    "PersonaRelationshipsTranslationsSchema",
    "PersonaResourceSchema",
    "PersonaSchema",
    "PersonasSchema",
    "PurchaseTenantPhoneNumberRequest",
    "PurchaseTenantPhoneNumberRequestData",
    "PurchaseTenantPhoneNumberRequestDataAttributes",
    "ReportAttributesSchema",
    "ReportRelationshipsSchema",
    "ReportRelationshipsTenantsDataSchema",
    "ReportRelationshipsTenantsSchema",
    "ReportResourceSchema",
    "ReportSchema",
    "ReportsSchema",
    "ResourceIdentifierSchema",
    "ResourceLinksSchema",
    "ResourceRelationshipsLinksSchema",
    "ResourceRelationshipsMetaSchema",
    "ResourceSchema",
    "ResourceTimestampsSchema",
    "ResourcesLinksSchema",
    "ResourcesMetaPageSchema",
    "ResourcesMetaSchema",
    "RoleAttributesSchema",
    "RoleRelationshipsPermissionsDataSchema",
    "RoleRelationshipsPermissionsSchema",
    "RoleRelationshipsSchema",
    "RoleRelationshipsUsersDataSchema",
    "RoleRelationshipsUsersSchema",
    "RoleResourceSchema",
    "RoleSchema",
    "RolesSchema",
    "TalentAlumniSchema",
    "TalentAttributesDesiredContractLengthSchema",
    "TalentAttributesDesiredEmploymentTypeSchema",
    "TalentAttributesDesiredRoleSchema",
    "TalentAttributesEmploymentTypeSchema",
    "TalentAttributesSchema",
    "TalentAttributesSocialLinkSchema",
    "TalentAvailabilityReceivedCriteriaSchema",
    "TalentReceivedCriteriaSchema",
    "TalentReferralSchema",
    "TalentReferralSchemaReferrer",
    "TalentRelationshipsCandidatesDataSchema",
    "TalentRelationshipsCandidatesSchema",
    "TalentRelationshipsFilesDataSchema",
    "TalentRelationshipsFilesSchema",
    "TalentRelationshipsOperationsDataSchema",
    "TalentRelationshipsOperationsSchema",
    "TalentRelationshipsSchema",
    "TalentRelationshipsTranslationsDataSchema",
    "TalentRelationshipsTranslationsSchema",
    "TalentResourceSchema",
    "TalentSchema",
    "TalentsSchema",
    "TenantAttributesAddressSchema",
    "TenantAttributesSchema",
    "TenantAttributesSettingsSchema",
    "TenantAttributesSettingsSchemaCalling",
    "TenantResourceSchema",
    "TenantSchema",
    "TenantUploadAttributesSchema",
    "TenantUploadResourceSchema",
    "TenantUploadSchema",
    "TenantsMetaPageSchema",
    "TenantsMetaSchema",
    "TenantsSchema",
    "TimelineAttributesSchema",
    "TimelineAttributesSchemaChangesValue",
    "TimelineAttributesSchemaSummaryValue",
    "TimelineAttributesSchemaSummaryValueUser",
    "TimelineAttributesSchemaTimestamps",
    "TimelineResourceSchema",
    "TimelineSchema",
    "TimelinesSchema",
    "TranslationAttributesSchema",
    "TranslationRelationshipsCandidateDataSchema",
    "TranslationRelationshipsCandidateSchema",
    "TranslationRelationshipsJobDataSchema",
    "TranslationRelationshipsJobSchema",
    "TranslationRelationshipsReportDataSchema",
    "TranslationRelationshipsReportSchema",
    "TranslationRelationshipsSchema",
    "TranslationRelationshipsTalentDataSchema",
    "TranslationRelationshipsTalentSchema",
    "TranslationResourceSchema",
    "TranslationSchema",
    "TranslationsSchema",
    "UpdateAdRequestBody",
    "UpdateAdRequestBodyData",
    "UpdateApikeyRequestBody",
    "UpdateApikeyRequestBodyData",
    "UpdateAssessmentRequestBody",
    "UpdateAssessmentRequestBodyData",
    "UpdateBrowserRequestBody",
    "UpdateBrowserRequestBodyData",
    "UpdateCallRequestBody",
    "UpdateCallRequestBodyData",
    "UpdateCandidateRequestBody",
    "UpdateCandidateRequestBodyData",
    "UpdateChatRequestBody",
    "UpdateChatRequestBodyData",
    "UpdateConversationRequestBody",
    "UpdateConversationRequestBodyData",
    "UpdateEmailRequestBody",
    "UpdateEmailRequestBodyData",
    "UpdateFileRequestBody",
    "UpdateFileRequestBodyData",
    "UpdateFinderRequestBody",
    "UpdateFinderRequestBodyData",
    "UpdateFormRequestBody",
    "UpdateFormRequestBodyData",
    "UpdateJobRequestBody",
    "UpdateJobRequestBodyData",
    "UpdateLinkRequestBody",
    "UpdateLinkRequestBodyData",
    "UpdateMeetingRequestBody",
    "UpdateMeetingRequestBodyData",
    "UpdateNoteRequestBody",
    "UpdateNoteRequestBodyData",
    "UpdateNotificationRequestBody",
    "UpdateNotificationRequestBodyData",
    "UpdateNotificationRequestBodyDataAttributes",
    "UpdateOperationRequestBody",
    "UpdateOperationRequestBodyData",
    "UpdatePersonaRequestBody",
    "UpdatePersonaRequestBodyData",
    "UpdateReportRequestBody",
    "UpdateReportRequestBodyData",
    "UpdateRoleRequestBody",
    "UpdateRoleRequestBodyData",
    "UpdateTalentRequestBody",
    "UpdateTalentRequestBodyData",
    "UpdateTenantRequestBody",
    "UpdateTenantRequestBodyData",
    "UpdateTranslationRequestBody",
    "UpdateTranslationRequestBodyData",
    "UpdateUserRequestBody",
    "UpdateUserRequestBodyData",
    "UpdateWebhookRequestBody",
    "UpdateWebhookRequestBodyData",
    "UserAttributesSchema",
    "UserHistoryEventSchema",
    "UserHistoryEventSchemaChallengeResponsesInner",
    "UserHistoryEventSchemaEventFeedback",
    "UserRelationshipsApikeysDataSchema",
    "UserRelationshipsApikeysSchema",
    "UserRelationshipsJobsDataSchema",
    "UserRelationshipsJobsSchema",
    "UserRelationshipsRoleDataSchema",
    "UserRelationshipsRoleSchema",
    "UserRelationshipsSchema",
    "UserResourceSchema",
    "UserSchema",
    "UserUploadAttributesSchema",
    "UserUploadResourceSchema",
    "UserUploadSchema",
    "UsersSchema",
    "WebhookAttributesSchema",
    "WebhookResourceSchema",
    "WebhookSchema",
    "WebhooksSchema",
]

# import apis into sdk package
from smartytalent_client.api.actions_api import ActionsApi as ActionsApi
from smartytalent_client.api.ads_api import AdsApi as AdsApi
from smartytalent_client.api.apikeys_api import ApikeysApi as ApikeysApi
from smartytalent_client.api.assessments_api import AssessmentsApi as AssessmentsApi
from smartytalent_client.api.browsers_api import BrowsersApi as BrowsersApi
from smartytalent_client.api.calls_api import CallsApi as CallsApi
from smartytalent_client.api.candidates_api import CandidatesApi as CandidatesApi
from smartytalent_client.api.chats_api import ChatsApi as ChatsApi
from smartytalent_client.api.conversations_api import ConversationsApi as ConversationsApi
from smartytalent_client.api.emails_api import EmailsApi as EmailsApi
from smartytalent_client.api.files_api import FilesApi as FilesApi
from smartytalent_client.api.finders_api import FindersApi as FindersApi
from smartytalent_client.api.forms_api import FormsApi as FormsApi
from smartytalent_client.api.jobs_api import JobsApi as JobsApi
from smartytalent_client.api.links_api import LinksApi as LinksApi
from smartytalent_client.api.meetings_api import MeetingsApi as MeetingsApi
from smartytalent_client.api.notes_api import NotesApi as NotesApi
from smartytalent_client.api.notifications_api import NotificationsApi as NotificationsApi
from smartytalent_client.api.operations_api import OperationsApi as OperationsApi
from smartytalent_client.api.personas_api import PersonasApi as PersonasApi
from smartytalent_client.api.reports_api import ReportsApi as ReportsApi
from smartytalent_client.api.roles_api import RolesApi as RolesApi
from smartytalent_client.api.runs_api import RunsApi as RunsApi
from smartytalent_client.api.talents_api import TalentsApi as TalentsApi
from smartytalent_client.api.tenants_api import TenantsApi as TenantsApi
from smartytalent_client.api.timelines_api import TimelinesApi as TimelinesApi
from smartytalent_client.api.translations_api import TranslationsApi as TranslationsApi
from smartytalent_client.api.triggers_api import TriggersApi as TriggersApi
from smartytalent_client.api.users_api import UsersApi as UsersApi
from smartytalent_client.api.webhooks_api import WebhooksApi as WebhooksApi
from smartytalent_client.api.workflows_api import WorkflowsApi as WorkflowsApi
from smartytalent_client.api.default_api import DefaultApi as DefaultApi

# import ApiClient
from smartytalent_client.api_response import ApiResponse as ApiResponse
from smartytalent_client.api_client import ApiClient as ApiClient
from smartytalent_client.configuration import Configuration as Configuration
from smartytalent_client.exceptions import OpenApiException as OpenApiException
from smartytalent_client.exceptions import ApiTypeError as ApiTypeError
from smartytalent_client.exceptions import ApiValueError as ApiValueError
from smartytalent_client.exceptions import ApiKeyError as ApiKeyError
from smartytalent_client.exceptions import ApiAttributeError as ApiAttributeError
from smartytalent_client.exceptions import ApiException as ApiException

# import models into sdk package
from smartytalent_client.models.ad_attributes_schema import AdAttributesSchema as AdAttributesSchema
from smartytalent_client.models.ad_attributes_schema_images_inner import AdAttributesSchemaImagesInner as AdAttributesSchemaImagesInner
from smartytalent_client.models.ad_relationships_job_data_schema import AdRelationshipsJobDataSchema as AdRelationshipsJobDataSchema
from smartytalent_client.models.ad_relationships_job_schema import AdRelationshipsJobSchema as AdRelationshipsJobSchema
from smartytalent_client.models.ad_relationships_schema import AdRelationshipsSchema as AdRelationshipsSchema
from smartytalent_client.models.ad_resource_schema import AdResourceSchema as AdResourceSchema
from smartytalent_client.models.ad_schema import AdSchema as AdSchema
from smartytalent_client.models.ads_schema import AdsSchema as AdsSchema
from smartytalent_client.models.apikey_attributes_schema import ApikeyAttributesSchema as ApikeyAttributesSchema
from smartytalent_client.models.apikey_relationships_schema import ApikeyRelationshipsSchema as ApikeyRelationshipsSchema
from smartytalent_client.models.apikey_relationships_user_data_schema import ApikeyRelationshipsUserDataSchema as ApikeyRelationshipsUserDataSchema
from smartytalent_client.models.apikey_relationships_user_schema import ApikeyRelationshipsUserSchema as ApikeyRelationshipsUserSchema
from smartytalent_client.models.apikey_resource_schema import ApikeyResourceSchema as ApikeyResourceSchema
from smartytalent_client.models.apikey_schema import ApikeySchema as ApikeySchema
from smartytalent_client.models.apikeys_schema import ApikeysSchema as ApikeysSchema
from smartytalent_client.models.assessment_attributes_schema import AssessmentAttributesSchema as AssessmentAttributesSchema
from smartytalent_client.models.assessment_relationships_candidate_data_schema import AssessmentRelationshipsCandidateDataSchema as AssessmentRelationshipsCandidateDataSchema
from smartytalent_client.models.assessment_relationships_candidate_schema import AssessmentRelationshipsCandidateSchema as AssessmentRelationshipsCandidateSchema
from smartytalent_client.models.assessment_relationships_job_data_schema import AssessmentRelationshipsJobDataSchema as AssessmentRelationshipsJobDataSchema
from smartytalent_client.models.assessment_relationships_job_schema import AssessmentRelationshipsJobSchema as AssessmentRelationshipsJobSchema
from smartytalent_client.models.assessment_relationships_schema import AssessmentRelationshipsSchema as AssessmentRelationshipsSchema
from smartytalent_client.models.assessment_resource_schema import AssessmentResourceSchema as AssessmentResourceSchema
from smartytalent_client.models.assessment_schema import AssessmentSchema as AssessmentSchema
from smartytalent_client.models.assessments_schema import AssessmentsSchema as AssessmentsSchema
from smartytalent_client.models.browser_attributes_schema import BrowserAttributesSchema as BrowserAttributesSchema
from smartytalent_client.models.browser_relationships_schema import BrowserRelationshipsSchema as BrowserRelationshipsSchema
from smartytalent_client.models.browser_relationships_translations_data_schema import BrowserRelationshipsTranslationsDataSchema as BrowserRelationshipsTranslationsDataSchema
from smartytalent_client.models.browser_relationships_translations_schema import BrowserRelationshipsTranslationsSchema as BrowserRelationshipsTranslationsSchema
from smartytalent_client.models.browser_resource_schema import BrowserResourceSchema as BrowserResourceSchema
from smartytalent_client.models.browser_schema import BrowserSchema as BrowserSchema
from smartytalent_client.models.browsers_schema import BrowsersSchema as BrowsersSchema
from smartytalent_client.models.call_attributes_schema import CallAttributesSchema as CallAttributesSchema
from smartytalent_client.models.call_relationships_schema import CallRelationshipsSchema as CallRelationshipsSchema
from smartytalent_client.models.call_relationships_translations_data_schema import CallRelationshipsTranslationsDataSchema as CallRelationshipsTranslationsDataSchema
from smartytalent_client.models.call_relationships_translations_schema import CallRelationshipsTranslationsSchema as CallRelationshipsTranslationsSchema
from smartytalent_client.models.call_resource_schema import CallResourceSchema as CallResourceSchema
from smartytalent_client.models.call_schema import CallSchema as CallSchema
from smartytalent_client.models.calls_schema import CallsSchema as CallsSchema
from smartytalent_client.models.candidate_attributes_schema import CandidateAttributesSchema as CandidateAttributesSchema
from smartytalent_client.models.candidate_criteria_schema import CandidateCriteriaSchema as CandidateCriteriaSchema
from smartytalent_client.models.candidate_relationships_job_data_schema import CandidateRelationshipsJobDataSchema as CandidateRelationshipsJobDataSchema
from smartytalent_client.models.candidate_relationships_job_schema import CandidateRelationshipsJobSchema as CandidateRelationshipsJobSchema
from smartytalent_client.models.candidate_relationships_operations_data_schema import CandidateRelationshipsOperationsDataSchema as CandidateRelationshipsOperationsDataSchema
from smartytalent_client.models.candidate_relationships_operations_schema import CandidateRelationshipsOperationsSchema as CandidateRelationshipsOperationsSchema
from smartytalent_client.models.candidate_relationships_schema import CandidateRelationshipsSchema as CandidateRelationshipsSchema
from smartytalent_client.models.candidate_relationships_talent_data_schema import CandidateRelationshipsTalentDataSchema as CandidateRelationshipsTalentDataSchema
from smartytalent_client.models.candidate_relationships_talent_schema import CandidateRelationshipsTalentSchema as CandidateRelationshipsTalentSchema
from smartytalent_client.models.candidate_relationships_translations_data_schema import CandidateRelationshipsTranslationsDataSchema as CandidateRelationshipsTranslationsDataSchema
from smartytalent_client.models.candidate_relationships_translations_schema import CandidateRelationshipsTranslationsSchema as CandidateRelationshipsTranslationsSchema
from smartytalent_client.models.candidate_resource_schema import CandidateResourceSchema as CandidateResourceSchema
from smartytalent_client.models.candidate_schema import CandidateSchema as CandidateSchema
from smartytalent_client.models.candidates_schema import CandidatesSchema as CandidatesSchema
from smartytalent_client.models.chat_attributes_schema import ChatAttributesSchema as ChatAttributesSchema
from smartytalent_client.models.chat_relationships_schema import ChatRelationshipsSchema as ChatRelationshipsSchema
from smartytalent_client.models.chat_relationships_translations_data_schema import ChatRelationshipsTranslationsDataSchema as ChatRelationshipsTranslationsDataSchema
from smartytalent_client.models.chat_relationships_translations_schema import ChatRelationshipsTranslationsSchema as ChatRelationshipsTranslationsSchema
from smartytalent_client.models.chat_resource_schema import ChatResourceSchema as ChatResourceSchema
from smartytalent_client.models.chat_schema import ChatSchema as ChatSchema
from smartytalent_client.models.chats_schema import ChatsSchema as ChatsSchema
from smartytalent_client.models.conversation_attributes_schema import ConversationAttributesSchema as ConversationAttributesSchema
from smartytalent_client.models.conversation_relationships_candidate_data_schema import ConversationRelationshipsCandidateDataSchema as ConversationRelationshipsCandidateDataSchema
from smartytalent_client.models.conversation_relationships_candidate_schema import ConversationRelationshipsCandidateSchema as ConversationRelationshipsCandidateSchema
from smartytalent_client.models.conversation_relationships_schema import ConversationRelationshipsSchema as ConversationRelationshipsSchema
from smartytalent_client.models.conversation_resource_schema import ConversationResourceSchema as ConversationResourceSchema
from smartytalent_client.models.conversation_schema import ConversationSchema as ConversationSchema
from smartytalent_client.models.conversations_schema import ConversationsSchema as ConversationsSchema
from smartytalent_client.models.create_ad_request_body import CreateAdRequestBody as CreateAdRequestBody
from smartytalent_client.models.create_ad_request_body_data import CreateAdRequestBodyData as CreateAdRequestBodyData
from smartytalent_client.models.create_apikey_request_body import CreateApikeyRequestBody as CreateApikeyRequestBody
from smartytalent_client.models.create_apikey_request_body_data import CreateApikeyRequestBodyData as CreateApikeyRequestBodyData
from smartytalent_client.models.create_assessment_request_body import CreateAssessmentRequestBody as CreateAssessmentRequestBody
from smartytalent_client.models.create_assessment_request_body_data import CreateAssessmentRequestBodyData as CreateAssessmentRequestBodyData
from smartytalent_client.models.create_browser_request_body import CreateBrowserRequestBody as CreateBrowserRequestBody
from smartytalent_client.models.create_browser_request_body_data import CreateBrowserRequestBodyData as CreateBrowserRequestBodyData
from smartytalent_client.models.create_call_request_body import CreateCallRequestBody as CreateCallRequestBody
from smartytalent_client.models.create_call_request_body_data import CreateCallRequestBodyData as CreateCallRequestBodyData
from smartytalent_client.models.create_candidate_request_body import CreateCandidateRequestBody as CreateCandidateRequestBody
from smartytalent_client.models.create_candidate_request_body_data import CreateCandidateRequestBodyData as CreateCandidateRequestBodyData
from smartytalent_client.models.create_chat_request_body import CreateChatRequestBody as CreateChatRequestBody
from smartytalent_client.models.create_chat_request_body_data import CreateChatRequestBodyData as CreateChatRequestBodyData
from smartytalent_client.models.create_conversation_request_body import CreateConversationRequestBody as CreateConversationRequestBody
from smartytalent_client.models.create_conversation_request_body_data import CreateConversationRequestBodyData as CreateConversationRequestBodyData
from smartytalent_client.models.create_email_request_body import CreateEmailRequestBody as CreateEmailRequestBody
from smartytalent_client.models.create_email_request_body_data import CreateEmailRequestBodyData as CreateEmailRequestBodyData
from smartytalent_client.models.create_file_request_body import CreateFileRequestBody as CreateFileRequestBody
from smartytalent_client.models.create_file_request_body_data import CreateFileRequestBodyData as CreateFileRequestBodyData
from smartytalent_client.models.create_finder_request_body import CreateFinderRequestBody as CreateFinderRequestBody
from smartytalent_client.models.create_finder_request_body_data import CreateFinderRequestBodyData as CreateFinderRequestBodyData
from smartytalent_client.models.create_form_request_body import CreateFormRequestBody as CreateFormRequestBody
from smartytalent_client.models.create_form_request_body_data import CreateFormRequestBodyData as CreateFormRequestBodyData
from smartytalent_client.models.create_job_request_body import CreateJobRequestBody as CreateJobRequestBody
from smartytalent_client.models.create_job_request_body_data import CreateJobRequestBodyData as CreateJobRequestBodyData
from smartytalent_client.models.create_link_request_body import CreateLinkRequestBody as CreateLinkRequestBody
from smartytalent_client.models.create_link_request_body_data import CreateLinkRequestBodyData as CreateLinkRequestBodyData
from smartytalent_client.models.create_meeting_ai_session_request_body import CreateMeetingAiSessionRequestBody as CreateMeetingAiSessionRequestBody
from smartytalent_client.models.create_meeting_ai_session_request_body_data import CreateMeetingAiSessionRequestBodyData as CreateMeetingAiSessionRequestBodyData
from smartytalent_client.models.create_meeting_attendee_request_body import CreateMeetingAttendeeRequestBody as CreateMeetingAttendeeRequestBody
from smartytalent_client.models.create_meeting_attendee_request_body_data import CreateMeetingAttendeeRequestBodyData as CreateMeetingAttendeeRequestBodyData
from smartytalent_client.models.create_meeting_request_body import CreateMeetingRequestBody as CreateMeetingRequestBody
from smartytalent_client.models.create_meeting_request_body_data import CreateMeetingRequestBodyData as CreateMeetingRequestBodyData
from smartytalent_client.models.create_note_request_body import CreateNoteRequestBody as CreateNoteRequestBody
from smartytalent_client.models.create_note_request_body_data import CreateNoteRequestBodyData as CreateNoteRequestBodyData
from smartytalent_client.models.create_notification_request_body import CreateNotificationRequestBody as CreateNotificationRequestBody
from smartytalent_client.models.create_notification_request_body_data import CreateNotificationRequestBodyData as CreateNotificationRequestBodyData
from smartytalent_client.models.create_operation_request_body import CreateOperationRequestBody as CreateOperationRequestBody
from smartytalent_client.models.create_operation_request_body_data import CreateOperationRequestBodyData as CreateOperationRequestBodyData
from smartytalent_client.models.create_persona_request_body import CreatePersonaRequestBody as CreatePersonaRequestBody
from smartytalent_client.models.create_persona_request_body_data import CreatePersonaRequestBodyData as CreatePersonaRequestBodyData
from smartytalent_client.models.create_report_request_body import CreateReportRequestBody as CreateReportRequestBody
from smartytalent_client.models.create_report_request_body_data import CreateReportRequestBodyData as CreateReportRequestBodyData
from smartytalent_client.models.create_role_request_body import CreateRoleRequestBody as CreateRoleRequestBody
from smartytalent_client.models.create_role_request_body_data import CreateRoleRequestBodyData as CreateRoleRequestBodyData
from smartytalent_client.models.create_talent_request_body import CreateTalentRequestBody as CreateTalentRequestBody
from smartytalent_client.models.create_talent_request_body_data import CreateTalentRequestBodyData as CreateTalentRequestBodyData
from smartytalent_client.models.create_tenant_request_body import CreateTenantRequestBody as CreateTenantRequestBody
from smartytalent_client.models.create_tenant_request_body_data import CreateTenantRequestBodyData as CreateTenantRequestBodyData
from smartytalent_client.models.create_tenant_upload_request_body import CreateTenantUploadRequestBody as CreateTenantUploadRequestBody
from smartytalent_client.models.create_tenant_upload_request_body_data import CreateTenantUploadRequestBodyData as CreateTenantUploadRequestBodyData
from smartytalent_client.models.create_tenant_upload_request_body_data_attributes import CreateTenantUploadRequestBodyDataAttributes as CreateTenantUploadRequestBodyDataAttributes
from smartytalent_client.models.create_translation_request_body import CreateTranslationRequestBody as CreateTranslationRequestBody
from smartytalent_client.models.create_translation_request_body_data import CreateTranslationRequestBodyData as CreateTranslationRequestBodyData
from smartytalent_client.models.create_user_request_body import CreateUserRequestBody as CreateUserRequestBody
from smartytalent_client.models.create_user_request_body_data import CreateUserRequestBodyData as CreateUserRequestBodyData
from smartytalent_client.models.create_user_upload_request_body import CreateUserUploadRequestBody as CreateUserUploadRequestBody
from smartytalent_client.models.create_user_upload_request_body_data import CreateUserUploadRequestBodyData as CreateUserUploadRequestBodyData
from smartytalent_client.models.create_user_upload_request_body_data_attributes import CreateUserUploadRequestBodyDataAttributes as CreateUserUploadRequestBodyDataAttributes
from smartytalent_client.models.create_webhook_request_body import CreateWebhookRequestBody as CreateWebhookRequestBody
from smartytalent_client.models.create_webhook_request_body_data import CreateWebhookRequestBodyData as CreateWebhookRequestBodyData
from smartytalent_client.models.email_attributes_schema import EmailAttributesSchema as EmailAttributesSchema
from smartytalent_client.models.email_relationships_candidate_data_schema import EmailRelationshipsCandidateDataSchema as EmailRelationshipsCandidateDataSchema
from smartytalent_client.models.email_relationships_candidate_schema import EmailRelationshipsCandidateSchema as EmailRelationshipsCandidateSchema
from smartytalent_client.models.email_relationships_operation_data_schema import EmailRelationshipsOperationDataSchema as EmailRelationshipsOperationDataSchema
from smartytalent_client.models.email_relationships_operation_schema import EmailRelationshipsOperationSchema as EmailRelationshipsOperationSchema
from smartytalent_client.models.email_relationships_report_data_schema import EmailRelationshipsReportDataSchema as EmailRelationshipsReportDataSchema
from smartytalent_client.models.email_relationships_report_schema import EmailRelationshipsReportSchema as EmailRelationshipsReportSchema
from smartytalent_client.models.email_relationships_schema import EmailRelationshipsSchema as EmailRelationshipsSchema
from smartytalent_client.models.email_relationships_translations_data_schema import EmailRelationshipsTranslationsDataSchema as EmailRelationshipsTranslationsDataSchema
from smartytalent_client.models.email_relationships_translations_schema import EmailRelationshipsTranslationsSchema as EmailRelationshipsTranslationsSchema
from smartytalent_client.models.email_resource_schema import EmailResourceSchema as EmailResourceSchema
from smartytalent_client.models.email_schema import EmailSchema as EmailSchema
from smartytalent_client.models.emails_schema import EmailsSchema as EmailsSchema
from smartytalent_client.models.error_object_schema import ErrorObjectSchema as ErrorObjectSchema
from smartytalent_client.models.error_schema import ErrorSchema as ErrorSchema
from smartytalent_client.models.file_attributes_schema import FileAttributesSchema as FileAttributesSchema
from smartytalent_client.models.file_relationships_link_data_schema import FileRelationshipsLinkDataSchema as FileRelationshipsLinkDataSchema
from smartytalent_client.models.file_relationships_link_schema import FileRelationshipsLinkSchema as FileRelationshipsLinkSchema
from smartytalent_client.models.file_relationships_schema import FileRelationshipsSchema as FileRelationshipsSchema
from smartytalent_client.models.file_resource_schema import FileResourceSchema as FileResourceSchema
from smartytalent_client.models.file_schema import FileSchema as FileSchema
from smartytalent_client.models.files_schema import FilesSchema as FilesSchema
from smartytalent_client.models.finder_attributes_schema import FinderAttributesSchema as FinderAttributesSchema
from smartytalent_client.models.finder_relationships_candidates_data_schema import FinderRelationshipsCandidatesDataSchema as FinderRelationshipsCandidatesDataSchema
from smartytalent_client.models.finder_relationships_candidates_schema import FinderRelationshipsCandidatesSchema as FinderRelationshipsCandidatesSchema
from smartytalent_client.models.finder_relationships_jobs_data_schema import FinderRelationshipsJobsDataSchema as FinderRelationshipsJobsDataSchema
from smartytalent_client.models.finder_relationships_jobs_schema import FinderRelationshipsJobsSchema as FinderRelationshipsJobsSchema
from smartytalent_client.models.finder_relationships_schema import FinderRelationshipsSchema as FinderRelationshipsSchema
from smartytalent_client.models.finder_relationships_talents_data_schema import FinderRelationshipsTalentsDataSchema as FinderRelationshipsTalentsDataSchema
from smartytalent_client.models.finder_relationships_talents_schema import FinderRelationshipsTalentsSchema as FinderRelationshipsTalentsSchema
from smartytalent_client.models.finder_relationships_users_data_schema import FinderRelationshipsUsersDataSchema as FinderRelationshipsUsersDataSchema
from smartytalent_client.models.finder_relationships_users_schema import FinderRelationshipsUsersSchema as FinderRelationshipsUsersSchema
from smartytalent_client.models.finder_resource_schema import FinderResourceSchema as FinderResourceSchema
from smartytalent_client.models.finder_schema import FinderSchema as FinderSchema
from smartytalent_client.models.finders_schema import FindersSchema as FindersSchema
from smartytalent_client.models.form_attributes_schema import FormAttributesSchema as FormAttributesSchema
from smartytalent_client.models.form_relationships_schema import FormRelationshipsSchema as FormRelationshipsSchema
from smartytalent_client.models.form_relationships_translations_data_schema import FormRelationshipsTranslationsDataSchema as FormRelationshipsTranslationsDataSchema
from smartytalent_client.models.form_relationships_translations_schema import FormRelationshipsTranslationsSchema as FormRelationshipsTranslationsSchema
from smartytalent_client.models.form_resource_schema import FormResourceSchema as FormResourceSchema
from smartytalent_client.models.form_schema import FormSchema as FormSchema
from smartytalent_client.models.forms_schema import FormsSchema as FormsSchema
from smartytalent_client.models.job_attributes_location_item_schema import JobAttributesLocationItemSchema as JobAttributesLocationItemSchema
from smartytalent_client.models.job_attributes_organization_address_schema import JobAttributesOrganizationAddressSchema as JobAttributesOrganizationAddressSchema
from smartytalent_client.models.job_attributes_organization_schema import JobAttributesOrganizationSchema as JobAttributesOrganizationSchema
from smartytalent_client.models.job_attributes_schema import JobAttributesSchema as JobAttributesSchema
from smartytalent_client.models.job_attributes_settings_conversation_candidate_interview_schema import JobAttributesSettingsConversationCandidateInterviewSchema as JobAttributesSettingsConversationCandidateInterviewSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_contact_schema import JobAttributesSettingsConversationEmailContactSchema as JobAttributesSettingsConversationEmailContactSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_delays_schema import JobAttributesSettingsConversationEmailDelaysSchema as JobAttributesSettingsConversationEmailDelaysSchema
from smartytalent_client.models.job_attributes_settings_conversation_email_schema import JobAttributesSettingsConversationEmailSchema as JobAttributesSettingsConversationEmailSchema
from smartytalent_client.models.job_attributes_settings_conversation_persona_interview_schema import JobAttributesSettingsConversationPersonaInterviewSchema as JobAttributesSettingsConversationPersonaInterviewSchema
from smartytalent_client.models.job_attributes_settings_conversation_schema import JobAttributesSettingsConversationSchema as JobAttributesSettingsConversationSchema
from smartytalent_client.models.job_attributes_settings_criterias_schema import JobAttributesSettingsCriteriasSchema as JobAttributesSettingsCriteriasSchema
from smartytalent_client.models.job_attributes_settings_operation_schema import JobAttributesSettingsOperationSchema as JobAttributesSettingsOperationSchema
from smartytalent_client.models.job_attributes_settings_persona_schema import JobAttributesSettingsPersonaSchema as JobAttributesSettingsPersonaSchema
from smartytalent_client.models.job_attributes_settings_schema import JobAttributesSettingsSchema as JobAttributesSettingsSchema
from smartytalent_client.models.job_attributes_site_item_schema import JobAttributesSiteItemSchema as JobAttributesSiteItemSchema
from smartytalent_client.models.job_criteria_schema import JobCriteriaSchema as JobCriteriaSchema
from smartytalent_client.models.job_relationships_candidates_data_schema import JobRelationshipsCandidatesDataSchema as JobRelationshipsCandidatesDataSchema
from smartytalent_client.models.job_relationships_candidates_schema import JobRelationshipsCandidatesSchema as JobRelationshipsCandidatesSchema
from smartytalent_client.models.job_relationships_conversations_data_schema import JobRelationshipsConversationsDataSchema as JobRelationshipsConversationsDataSchema
from smartytalent_client.models.job_relationships_conversations_schema import JobRelationshipsConversationsSchema as JobRelationshipsConversationsSchema
from smartytalent_client.models.job_relationships_operations_data_schema import JobRelationshipsOperationsDataSchema as JobRelationshipsOperationsDataSchema
from smartytalent_client.models.job_relationships_operations_schema import JobRelationshipsOperationsSchema as JobRelationshipsOperationsSchema
from smartytalent_client.models.job_relationships_personas_data_schema import JobRelationshipsPersonasDataSchema as JobRelationshipsPersonasDataSchema
from smartytalent_client.models.job_relationships_personas_schema import JobRelationshipsPersonasSchema as JobRelationshipsPersonasSchema
from smartytalent_client.models.job_relationships_schema import JobRelationshipsSchema as JobRelationshipsSchema
from smartytalent_client.models.job_relationships_translations_data_schema import JobRelationshipsTranslationsDataSchema as JobRelationshipsTranslationsDataSchema
from smartytalent_client.models.job_relationships_translations_schema import JobRelationshipsTranslationsSchema as JobRelationshipsTranslationsSchema
from smartytalent_client.models.job_resource_schema import JobResourceSchema as JobResourceSchema
from smartytalent_client.models.job_schema import JobSchema as JobSchema
from smartytalent_client.models.jobs_schema import JobsSchema as JobsSchema
from smartytalent_client.models.link_attributes_schema import LinkAttributesSchema as LinkAttributesSchema
from smartytalent_client.models.link_relationships_file_data_schema import LinkRelationshipsFileDataSchema as LinkRelationshipsFileDataSchema
from smartytalent_client.models.link_relationships_file_schema import LinkRelationshipsFileSchema as LinkRelationshipsFileSchema
from smartytalent_client.models.link_relationships_schema import LinkRelationshipsSchema as LinkRelationshipsSchema
from smartytalent_client.models.link_resource_schema import LinkResourceSchema as LinkResourceSchema
from smartytalent_client.models.link_schema import LinkSchema as LinkSchema
from smartytalent_client.models.links_schema import LinksSchema as LinksSchema
from smartytalent_client.models.list_candidate_jobs_relationship import ListCandidateJobsRelationship as ListCandidateJobsRelationship
from smartytalent_client.models.list_candidate_talents_relationship import ListCandidateTalentsRelationship as ListCandidateTalentsRelationship
from smartytalent_client.models.list_job_candidates_relationship import ListJobCandidatesRelationship as ListJobCandidatesRelationship
from smartytalent_client.models.list_role_users_relationship import ListRoleUsersRelationship as ListRoleUsersRelationship
from smartytalent_client.models.list_talent_candidates_relationship import ListTalentCandidatesRelationship as ListTalentCandidatesRelationship
from smartytalent_client.models.list_user_apikeys_relationship import ListUserApikeysRelationship as ListUserApikeysRelationship
from smartytalent_client.models.list_user_jobs_relationship import ListUserJobsRelationship as ListUserJobsRelationship
from smartytalent_client.models.list_user_roles_relationship import ListUserRolesRelationship as ListUserRolesRelationship
from smartytalent_client.models.meeting_ai_session_attributes_schema import MeetingAiSessionAttributesSchema as MeetingAiSessionAttributesSchema
from smartytalent_client.models.meeting_ai_session_attributes_schema_realtime_session import MeetingAiSessionAttributesSchemaRealtimeSession as MeetingAiSessionAttributesSchemaRealtimeSession
from smartytalent_client.models.meeting_ai_session_resource_schema import MeetingAiSessionResourceSchema as MeetingAiSessionResourceSchema
from smartytalent_client.models.meeting_ai_session_schema import MeetingAiSessionSchema as MeetingAiSessionSchema
from smartytalent_client.models.meeting_ai_session_settings_schema import MeetingAiSessionSettingsSchema as MeetingAiSessionSettingsSchema
from smartytalent_client.models.meeting_attendee_attributes_schema import MeetingAttendeeAttributesSchema as MeetingAttendeeAttributesSchema
from smartytalent_client.models.meeting_attendee_resource_schema import MeetingAttendeeResourceSchema as MeetingAttendeeResourceSchema
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships import MeetingAttendeeResourceSchemaAllOfRelationships as MeetingAttendeeResourceSchemaAllOfRelationships
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting import MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting as MeetingAttendeeResourceSchemaAllOfRelationshipsMeeting
from smartytalent_client.models.meeting_attendee_resource_schema_all_of_relationships_meeting_data import MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData as MeetingAttendeeResourceSchemaAllOfRelationshipsMeetingData
from smartytalent_client.models.meeting_attendee_response_attributes_schema import MeetingAttendeeResponseAttributesSchema as MeetingAttendeeResponseAttributesSchema
from smartytalent_client.models.meeting_attendee_schema import MeetingAttendeeSchema as MeetingAttendeeSchema
from smartytalent_client.models.meeting_attributes_schema import MeetingAttributesSchema as MeetingAttributesSchema
from smartytalent_client.models.meeting_lobby_attributes_schema import MeetingLobbyAttributesSchema as MeetingLobbyAttributesSchema
from smartytalent_client.models.meeting_lobby_resource_schema import MeetingLobbyResourceSchema as MeetingLobbyResourceSchema
from smartytalent_client.models.meeting_lobby_schema import MeetingLobbySchema as MeetingLobbySchema
from smartytalent_client.models.meeting_relationships_participants_data_schema import MeetingRelationshipsParticipantsDataSchema as MeetingRelationshipsParticipantsDataSchema
from smartytalent_client.models.meeting_relationships_participants_schema import MeetingRelationshipsParticipantsSchema as MeetingRelationshipsParticipantsSchema
from smartytalent_client.models.meeting_relationships_schema import MeetingRelationshipsSchema as MeetingRelationshipsSchema
from smartytalent_client.models.meeting_resource_schema import MeetingResourceSchema as MeetingResourceSchema
from smartytalent_client.models.meeting_schema import MeetingSchema as MeetingSchema
from smartytalent_client.models.meeting_transcription_attributes_schema import MeetingTranscriptionAttributesSchema as MeetingTranscriptionAttributesSchema
from smartytalent_client.models.meeting_transcription_request_body import MeetingTranscriptionRequestBody as MeetingTranscriptionRequestBody
from smartytalent_client.models.meeting_transcription_request_body_data import MeetingTranscriptionRequestBodyData as MeetingTranscriptionRequestBodyData
from smartytalent_client.models.meeting_transcription_schema import MeetingTranscriptionSchema as MeetingTranscriptionSchema
from smartytalent_client.models.meeting_transcription_schema_data import MeetingTranscriptionSchemaData as MeetingTranscriptionSchemaData
from smartytalent_client.models.meeting_transcription_settings_schema import MeetingTranscriptionSettingsSchema as MeetingTranscriptionSettingsSchema
from smartytalent_client.models.meetings_schema import MeetingsSchema as MeetingsSchema
from smartytalent_client.models.note_attributes_schema import NoteAttributesSchema as NoteAttributesSchema
from smartytalent_client.models.note_relationships_candidate_data_schema import NoteRelationshipsCandidateDataSchema as NoteRelationshipsCandidateDataSchema
from smartytalent_client.models.note_relationships_candidate_schema import NoteRelationshipsCandidateSchema as NoteRelationshipsCandidateSchema
from smartytalent_client.models.note_relationships_operation_data_schema import NoteRelationshipsOperationDataSchema as NoteRelationshipsOperationDataSchema
from smartytalent_client.models.note_relationships_operation_schema import NoteRelationshipsOperationSchema as NoteRelationshipsOperationSchema
from smartytalent_client.models.note_relationships_report_data_schema import NoteRelationshipsReportDataSchema as NoteRelationshipsReportDataSchema
from smartytalent_client.models.note_relationships_report_schema import NoteRelationshipsReportSchema as NoteRelationshipsReportSchema
from smartytalent_client.models.note_relationships_schema import NoteRelationshipsSchema as NoteRelationshipsSchema
from smartytalent_client.models.note_relationships_translations_data_schema import NoteRelationshipsTranslationsDataSchema as NoteRelationshipsTranslationsDataSchema
from smartytalent_client.models.note_relationships_translations_schema import NoteRelationshipsTranslationsSchema as NoteRelationshipsTranslationsSchema
from smartytalent_client.models.note_resource_schema import NoteResourceSchema as NoteResourceSchema
from smartytalent_client.models.note_schema import NoteSchema as NoteSchema
from smartytalent_client.models.notes_schema import NotesSchema as NotesSchema
from smartytalent_client.models.notification_attributes_schema import NotificationAttributesSchema as NotificationAttributesSchema
from smartytalent_client.models.notification_relationships_schema import NotificationRelationshipsSchema as NotificationRelationshipsSchema
from smartytalent_client.models.notification_relationships_schema_users import NotificationRelationshipsSchemaUsers as NotificationRelationshipsSchemaUsers
from smartytalent_client.models.notification_relationships_schema_users_data_inner import NotificationRelationshipsSchemaUsersDataInner as NotificationRelationshipsSchemaUsersDataInner
from smartytalent_client.models.notification_resource_schema import NotificationResourceSchema as NotificationResourceSchema
from smartytalent_client.models.notification_schema import NotificationSchema as NotificationSchema
from smartytalent_client.models.notifications_schema import NotificationsSchema as NotificationsSchema
from smartytalent_client.models.operation_attributes_schema import OperationAttributesSchema as OperationAttributesSchema
from smartytalent_client.models.operation_relationships_candidate_data_schema import OperationRelationshipsCandidateDataSchema as OperationRelationshipsCandidateDataSchema
from smartytalent_client.models.operation_relationships_candidate_schema import OperationRelationshipsCandidateSchema as OperationRelationshipsCandidateSchema
from smartytalent_client.models.operation_relationships_job_data_schema import OperationRelationshipsJobDataSchema as OperationRelationshipsJobDataSchema
from smartytalent_client.models.operation_relationships_job_schema import OperationRelationshipsJobSchema as OperationRelationshipsJobSchema
from smartytalent_client.models.operation_relationships_schema import OperationRelationshipsSchema as OperationRelationshipsSchema
from smartytalent_client.models.operation_resource_schema import OperationResourceSchema as OperationResourceSchema
from smartytalent_client.models.operation_schema import OperationSchema as OperationSchema
from smartytalent_client.models.operations_schema import OperationsSchema as OperationsSchema
from smartytalent_client.models.persona_attributes_schema import PersonaAttributesSchema as PersonaAttributesSchema
from smartytalent_client.models.persona_relationships_candidates_data_schema import PersonaRelationshipsCandidatesDataSchema as PersonaRelationshipsCandidatesDataSchema
from smartytalent_client.models.persona_relationships_candidates_schema import PersonaRelationshipsCandidatesSchema as PersonaRelationshipsCandidatesSchema
from smartytalent_client.models.persona_relationships_operations_data_schema import PersonaRelationshipsOperationsDataSchema as PersonaRelationshipsOperationsDataSchema
from smartytalent_client.models.persona_relationships_operations_schema import PersonaRelationshipsOperationsSchema as PersonaRelationshipsOperationsSchema
from smartytalent_client.models.persona_relationships_schema import PersonaRelationshipsSchema as PersonaRelationshipsSchema
from smartytalent_client.models.persona_relationships_talents_data_schema import PersonaRelationshipsTalentsDataSchema as PersonaRelationshipsTalentsDataSchema
from smartytalent_client.models.persona_relationships_talents_schema import PersonaRelationshipsTalentsSchema as PersonaRelationshipsTalentsSchema
from smartytalent_client.models.persona_relationships_translations_data_schema import PersonaRelationshipsTranslationsDataSchema as PersonaRelationshipsTranslationsDataSchema
from smartytalent_client.models.persona_relationships_translations_schema import PersonaRelationshipsTranslationsSchema as PersonaRelationshipsTranslationsSchema
from smartytalent_client.models.persona_resource_schema import PersonaResourceSchema as PersonaResourceSchema
from smartytalent_client.models.persona_schema import PersonaSchema as PersonaSchema
from smartytalent_client.models.personas_schema import PersonasSchema as PersonasSchema
from smartytalent_client.models.purchase_tenant_phone_number_request import PurchaseTenantPhoneNumberRequest as PurchaseTenantPhoneNumberRequest
from smartytalent_client.models.purchase_tenant_phone_number_request_data import PurchaseTenantPhoneNumberRequestData as PurchaseTenantPhoneNumberRequestData
from smartytalent_client.models.purchase_tenant_phone_number_request_data_attributes import PurchaseTenantPhoneNumberRequestDataAttributes as PurchaseTenantPhoneNumberRequestDataAttributes
from smartytalent_client.models.report_attributes_schema import ReportAttributesSchema as ReportAttributesSchema
from smartytalent_client.models.report_relationships_schema import ReportRelationshipsSchema as ReportRelationshipsSchema
from smartytalent_client.models.report_relationships_tenants_data_schema import ReportRelationshipsTenantsDataSchema as ReportRelationshipsTenantsDataSchema
from smartytalent_client.models.report_relationships_tenants_schema import ReportRelationshipsTenantsSchema as ReportRelationshipsTenantsSchema
from smartytalent_client.models.report_resource_schema import ReportResourceSchema as ReportResourceSchema
from smartytalent_client.models.report_schema import ReportSchema as ReportSchema
from smartytalent_client.models.reports_schema import ReportsSchema as ReportsSchema
from smartytalent_client.models.resource_identifier_schema import ResourceIdentifierSchema as ResourceIdentifierSchema
from smartytalent_client.models.resource_links_schema import ResourceLinksSchema as ResourceLinksSchema
from smartytalent_client.models.resource_relationships_links_schema import ResourceRelationshipsLinksSchema as ResourceRelationshipsLinksSchema
from smartytalent_client.models.resource_relationships_meta_schema import ResourceRelationshipsMetaSchema as ResourceRelationshipsMetaSchema
from smartytalent_client.models.resource_schema import ResourceSchema as ResourceSchema
from smartytalent_client.models.resource_timestamps_schema import ResourceTimestampsSchema as ResourceTimestampsSchema
from smartytalent_client.models.resources_links_schema import ResourcesLinksSchema as ResourcesLinksSchema
from smartytalent_client.models.resources_meta_page_schema import ResourcesMetaPageSchema as ResourcesMetaPageSchema
from smartytalent_client.models.resources_meta_schema import ResourcesMetaSchema as ResourcesMetaSchema
from smartytalent_client.models.role_attributes_schema import RoleAttributesSchema as RoleAttributesSchema
from smartytalent_client.models.role_relationships_permissions_data_schema import RoleRelationshipsPermissionsDataSchema as RoleRelationshipsPermissionsDataSchema
from smartytalent_client.models.role_relationships_permissions_schema import RoleRelationshipsPermissionsSchema as RoleRelationshipsPermissionsSchema
from smartytalent_client.models.role_relationships_schema import RoleRelationshipsSchema as RoleRelationshipsSchema
from smartytalent_client.models.role_relationships_users_data_schema import RoleRelationshipsUsersDataSchema as RoleRelationshipsUsersDataSchema
from smartytalent_client.models.role_relationships_users_schema import RoleRelationshipsUsersSchema as RoleRelationshipsUsersSchema
from smartytalent_client.models.role_resource_schema import RoleResourceSchema as RoleResourceSchema
from smartytalent_client.models.role_schema import RoleSchema as RoleSchema
from smartytalent_client.models.roles_schema import RolesSchema as RolesSchema
from smartytalent_client.models.talent_alumni_schema import TalentAlumniSchema as TalentAlumniSchema
from smartytalent_client.models.talent_attributes_desired_contract_length_schema import TalentAttributesDesiredContractLengthSchema as TalentAttributesDesiredContractLengthSchema
from smartytalent_client.models.talent_attributes_desired_employment_type_schema import TalentAttributesDesiredEmploymentTypeSchema as TalentAttributesDesiredEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_desired_role_schema import TalentAttributesDesiredRoleSchema as TalentAttributesDesiredRoleSchema
from smartytalent_client.models.talent_attributes_employment_type_schema import TalentAttributesEmploymentTypeSchema as TalentAttributesEmploymentTypeSchema
from smartytalent_client.models.talent_attributes_schema import TalentAttributesSchema as TalentAttributesSchema
from smartytalent_client.models.talent_attributes_social_link_schema import TalentAttributesSocialLinkSchema as TalentAttributesSocialLinkSchema
from smartytalent_client.models.talent_availability_received_criteria_schema import TalentAvailabilityReceivedCriteriaSchema as TalentAvailabilityReceivedCriteriaSchema
from smartytalent_client.models.talent_received_criteria_schema import TalentReceivedCriteriaSchema as TalentReceivedCriteriaSchema
from smartytalent_client.models.talent_referral_schema import TalentReferralSchema as TalentReferralSchema
from smartytalent_client.models.talent_referral_schema_referrer import TalentReferralSchemaReferrer as TalentReferralSchemaReferrer
from smartytalent_client.models.talent_relationships_candidates_data_schema import TalentRelationshipsCandidatesDataSchema as TalentRelationshipsCandidatesDataSchema
from smartytalent_client.models.talent_relationships_candidates_schema import TalentRelationshipsCandidatesSchema as TalentRelationshipsCandidatesSchema
from smartytalent_client.models.talent_relationships_files_data_schema import TalentRelationshipsFilesDataSchema as TalentRelationshipsFilesDataSchema
from smartytalent_client.models.talent_relationships_files_schema import TalentRelationshipsFilesSchema as TalentRelationshipsFilesSchema
from smartytalent_client.models.talent_relationships_operations_data_schema import TalentRelationshipsOperationsDataSchema as TalentRelationshipsOperationsDataSchema
from smartytalent_client.models.talent_relationships_operations_schema import TalentRelationshipsOperationsSchema as TalentRelationshipsOperationsSchema
from smartytalent_client.models.talent_relationships_schema import TalentRelationshipsSchema as TalentRelationshipsSchema
from smartytalent_client.models.talent_relationships_translations_data_schema import TalentRelationshipsTranslationsDataSchema as TalentRelationshipsTranslationsDataSchema
from smartytalent_client.models.talent_relationships_translations_schema import TalentRelationshipsTranslationsSchema as TalentRelationshipsTranslationsSchema
from smartytalent_client.models.talent_resource_schema import TalentResourceSchema as TalentResourceSchema
from smartytalent_client.models.talent_schema import TalentSchema as TalentSchema
from smartytalent_client.models.talents_schema import TalentsSchema as TalentsSchema
from smartytalent_client.models.tenant_attributes_address_schema import TenantAttributesAddressSchema as TenantAttributesAddressSchema
from smartytalent_client.models.tenant_attributes_schema import TenantAttributesSchema as TenantAttributesSchema
from smartytalent_client.models.tenant_attributes_settings_schema import TenantAttributesSettingsSchema as TenantAttributesSettingsSchema
from smartytalent_client.models.tenant_attributes_settings_schema_calling import TenantAttributesSettingsSchemaCalling as TenantAttributesSettingsSchemaCalling
from smartytalent_client.models.tenant_resource_schema import TenantResourceSchema as TenantResourceSchema
from smartytalent_client.models.tenant_schema import TenantSchema as TenantSchema
from smartytalent_client.models.tenant_upload_attributes_schema import TenantUploadAttributesSchema as TenantUploadAttributesSchema
from smartytalent_client.models.tenant_upload_resource_schema import TenantUploadResourceSchema as TenantUploadResourceSchema
from smartytalent_client.models.tenant_upload_schema import TenantUploadSchema as TenantUploadSchema
from smartytalent_client.models.tenants_meta_page_schema import TenantsMetaPageSchema as TenantsMetaPageSchema
from smartytalent_client.models.tenants_meta_schema import TenantsMetaSchema as TenantsMetaSchema
from smartytalent_client.models.tenants_schema import TenantsSchema as TenantsSchema
from smartytalent_client.models.timeline_attributes_schema import TimelineAttributesSchema as TimelineAttributesSchema
from smartytalent_client.models.timeline_attributes_schema_changes_value import TimelineAttributesSchemaChangesValue as TimelineAttributesSchemaChangesValue
from smartytalent_client.models.timeline_attributes_schema_summary_value import TimelineAttributesSchemaSummaryValue as TimelineAttributesSchemaSummaryValue
from smartytalent_client.models.timeline_attributes_schema_summary_value_user import TimelineAttributesSchemaSummaryValueUser as TimelineAttributesSchemaSummaryValueUser
from smartytalent_client.models.timeline_attributes_schema_timestamps import TimelineAttributesSchemaTimestamps as TimelineAttributesSchemaTimestamps
from smartytalent_client.models.timeline_resource_schema import TimelineResourceSchema as TimelineResourceSchema
from smartytalent_client.models.timeline_schema import TimelineSchema as TimelineSchema
from smartytalent_client.models.timelines_schema import TimelinesSchema as TimelinesSchema
from smartytalent_client.models.translation_attributes_schema import TranslationAttributesSchema as TranslationAttributesSchema
from smartytalent_client.models.translation_relationships_candidate_data_schema import TranslationRelationshipsCandidateDataSchema as TranslationRelationshipsCandidateDataSchema
from smartytalent_client.models.translation_relationships_candidate_schema import TranslationRelationshipsCandidateSchema as TranslationRelationshipsCandidateSchema
from smartytalent_client.models.translation_relationships_job_data_schema import TranslationRelationshipsJobDataSchema as TranslationRelationshipsJobDataSchema
from smartytalent_client.models.translation_relationships_job_schema import TranslationRelationshipsJobSchema as TranslationRelationshipsJobSchema
from smartytalent_client.models.translation_relationships_report_data_schema import TranslationRelationshipsReportDataSchema as TranslationRelationshipsReportDataSchema
from smartytalent_client.models.translation_relationships_report_schema import TranslationRelationshipsReportSchema as TranslationRelationshipsReportSchema
from smartytalent_client.models.translation_relationships_schema import TranslationRelationshipsSchema as TranslationRelationshipsSchema
from smartytalent_client.models.translation_relationships_talent_data_schema import TranslationRelationshipsTalentDataSchema as TranslationRelationshipsTalentDataSchema
from smartytalent_client.models.translation_relationships_talent_schema import TranslationRelationshipsTalentSchema as TranslationRelationshipsTalentSchema
from smartytalent_client.models.translation_resource_schema import TranslationResourceSchema as TranslationResourceSchema
from smartytalent_client.models.translation_schema import TranslationSchema as TranslationSchema
from smartytalent_client.models.translations_schema import TranslationsSchema as TranslationsSchema
from smartytalent_client.models.update_ad_request_body import UpdateAdRequestBody as UpdateAdRequestBody
from smartytalent_client.models.update_ad_request_body_data import UpdateAdRequestBodyData as UpdateAdRequestBodyData
from smartytalent_client.models.update_apikey_request_body import UpdateApikeyRequestBody as UpdateApikeyRequestBody
from smartytalent_client.models.update_apikey_request_body_data import UpdateApikeyRequestBodyData as UpdateApikeyRequestBodyData
from smartytalent_client.models.update_assessment_request_body import UpdateAssessmentRequestBody as UpdateAssessmentRequestBody
from smartytalent_client.models.update_assessment_request_body_data import UpdateAssessmentRequestBodyData as UpdateAssessmentRequestBodyData
from smartytalent_client.models.update_browser_request_body import UpdateBrowserRequestBody as UpdateBrowserRequestBody
from smartytalent_client.models.update_browser_request_body_data import UpdateBrowserRequestBodyData as UpdateBrowserRequestBodyData
from smartytalent_client.models.update_call_request_body import UpdateCallRequestBody as UpdateCallRequestBody
from smartytalent_client.models.update_call_request_body_data import UpdateCallRequestBodyData as UpdateCallRequestBodyData
from smartytalent_client.models.update_candidate_request_body import UpdateCandidateRequestBody as UpdateCandidateRequestBody
from smartytalent_client.models.update_candidate_request_body_data import UpdateCandidateRequestBodyData as UpdateCandidateRequestBodyData
from smartytalent_client.models.update_chat_request_body import UpdateChatRequestBody as UpdateChatRequestBody
from smartytalent_client.models.update_chat_request_body_data import UpdateChatRequestBodyData as UpdateChatRequestBodyData
from smartytalent_client.models.update_conversation_request_body import UpdateConversationRequestBody as UpdateConversationRequestBody
from smartytalent_client.models.update_conversation_request_body_data import UpdateConversationRequestBodyData as UpdateConversationRequestBodyData
from smartytalent_client.models.update_email_request_body import UpdateEmailRequestBody as UpdateEmailRequestBody
from smartytalent_client.models.update_email_request_body_data import UpdateEmailRequestBodyData as UpdateEmailRequestBodyData
from smartytalent_client.models.update_file_request_body import UpdateFileRequestBody as UpdateFileRequestBody
from smartytalent_client.models.update_file_request_body_data import UpdateFileRequestBodyData as UpdateFileRequestBodyData
from smartytalent_client.models.update_finder_request_body import UpdateFinderRequestBody as UpdateFinderRequestBody
from smartytalent_client.models.update_finder_request_body_data import UpdateFinderRequestBodyData as UpdateFinderRequestBodyData
from smartytalent_client.models.update_form_request_body import UpdateFormRequestBody as UpdateFormRequestBody
from smartytalent_client.models.update_form_request_body_data import UpdateFormRequestBodyData as UpdateFormRequestBodyData
from smartytalent_client.models.update_job_request_body import UpdateJobRequestBody as UpdateJobRequestBody
from smartytalent_client.models.update_job_request_body_data import UpdateJobRequestBodyData as UpdateJobRequestBodyData
from smartytalent_client.models.update_link_request_body import UpdateLinkRequestBody as UpdateLinkRequestBody
from smartytalent_client.models.update_link_request_body_data import UpdateLinkRequestBodyData as UpdateLinkRequestBodyData
from smartytalent_client.models.update_meeting_request_body import UpdateMeetingRequestBody as UpdateMeetingRequestBody
from smartytalent_client.models.update_meeting_request_body_data import UpdateMeetingRequestBodyData as UpdateMeetingRequestBodyData
from smartytalent_client.models.update_note_request_body import UpdateNoteRequestBody as UpdateNoteRequestBody
from smartytalent_client.models.update_note_request_body_data import UpdateNoteRequestBodyData as UpdateNoteRequestBodyData
from smartytalent_client.models.update_notification_request_body import UpdateNotificationRequestBody as UpdateNotificationRequestBody
from smartytalent_client.models.update_notification_request_body_data import UpdateNotificationRequestBodyData as UpdateNotificationRequestBodyData
from smartytalent_client.models.update_notification_request_body_data_attributes import UpdateNotificationRequestBodyDataAttributes as UpdateNotificationRequestBodyDataAttributes
from smartytalent_client.models.update_operation_request_body import UpdateOperationRequestBody as UpdateOperationRequestBody
from smartytalent_client.models.update_operation_request_body_data import UpdateOperationRequestBodyData as UpdateOperationRequestBodyData
from smartytalent_client.models.update_persona_request_body import UpdatePersonaRequestBody as UpdatePersonaRequestBody
from smartytalent_client.models.update_persona_request_body_data import UpdatePersonaRequestBodyData as UpdatePersonaRequestBodyData
from smartytalent_client.models.update_report_request_body import UpdateReportRequestBody as UpdateReportRequestBody
from smartytalent_client.models.update_report_request_body_data import UpdateReportRequestBodyData as UpdateReportRequestBodyData
from smartytalent_client.models.update_role_request_body import UpdateRoleRequestBody as UpdateRoleRequestBody
from smartytalent_client.models.update_role_request_body_data import UpdateRoleRequestBodyData as UpdateRoleRequestBodyData
from smartytalent_client.models.update_talent_request_body import UpdateTalentRequestBody as UpdateTalentRequestBody
from smartytalent_client.models.update_talent_request_body_data import UpdateTalentRequestBodyData as UpdateTalentRequestBodyData
from smartytalent_client.models.update_tenant_request_body import UpdateTenantRequestBody as UpdateTenantRequestBody
from smartytalent_client.models.update_tenant_request_body_data import UpdateTenantRequestBodyData as UpdateTenantRequestBodyData
from smartytalent_client.models.update_translation_request_body import UpdateTranslationRequestBody as UpdateTranslationRequestBody
from smartytalent_client.models.update_translation_request_body_data import UpdateTranslationRequestBodyData as UpdateTranslationRequestBodyData
from smartytalent_client.models.update_user_request_body import UpdateUserRequestBody as UpdateUserRequestBody
from smartytalent_client.models.update_user_request_body_data import UpdateUserRequestBodyData as UpdateUserRequestBodyData
from smartytalent_client.models.update_webhook_request_body import UpdateWebhookRequestBody as UpdateWebhookRequestBody
from smartytalent_client.models.update_webhook_request_body_data import UpdateWebhookRequestBodyData as UpdateWebhookRequestBodyData
from smartytalent_client.models.user_attributes_schema import UserAttributesSchema as UserAttributesSchema
from smartytalent_client.models.user_history_event_schema import UserHistoryEventSchema as UserHistoryEventSchema
from smartytalent_client.models.user_history_event_schema_challenge_responses_inner import UserHistoryEventSchemaChallengeResponsesInner as UserHistoryEventSchemaChallengeResponsesInner
from smartytalent_client.models.user_history_event_schema_event_feedback import UserHistoryEventSchemaEventFeedback as UserHistoryEventSchemaEventFeedback
from smartytalent_client.models.user_relationships_apikeys_data_schema import UserRelationshipsApikeysDataSchema as UserRelationshipsApikeysDataSchema
from smartytalent_client.models.user_relationships_apikeys_schema import UserRelationshipsApikeysSchema as UserRelationshipsApikeysSchema
from smartytalent_client.models.user_relationships_jobs_data_schema import UserRelationshipsJobsDataSchema as UserRelationshipsJobsDataSchema
from smartytalent_client.models.user_relationships_jobs_schema import UserRelationshipsJobsSchema as UserRelationshipsJobsSchema
from smartytalent_client.models.user_relationships_role_data_schema import UserRelationshipsRoleDataSchema as UserRelationshipsRoleDataSchema
from smartytalent_client.models.user_relationships_role_schema import UserRelationshipsRoleSchema as UserRelationshipsRoleSchema
from smartytalent_client.models.user_relationships_schema import UserRelationshipsSchema as UserRelationshipsSchema
from smartytalent_client.models.user_resource_schema import UserResourceSchema as UserResourceSchema
from smartytalent_client.models.user_schema import UserSchema as UserSchema
from smartytalent_client.models.user_upload_attributes_schema import UserUploadAttributesSchema as UserUploadAttributesSchema
from smartytalent_client.models.user_upload_resource_schema import UserUploadResourceSchema as UserUploadResourceSchema
from smartytalent_client.models.user_upload_schema import UserUploadSchema as UserUploadSchema
from smartytalent_client.models.users_schema import UsersSchema as UsersSchema
from smartytalent_client.models.webhook_attributes_schema import WebhookAttributesSchema as WebhookAttributesSchema
from smartytalent_client.models.webhook_resource_schema import WebhookResourceSchema as WebhookResourceSchema
from smartytalent_client.models.webhook_schema import WebhookSchema as WebhookSchema
from smartytalent_client.models.webhooks_schema import WebhooksSchema as WebhooksSchema

